'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var React = require('react');
var React__default = _interopDefault(React);
var reactJss = require('react-jss');
var parser = _interopDefault(require('html-react-parser'));
var reactRouterDom = require('react-router-dom');
var reactTransitionGroup = require('react-transition-group');
var keys = _interopDefault(require('lodash/keys'));
var debounce = _interopDefault(require('lodash/debounce'));
var isEmpty = _interopDefault(require('validator/lib/isEmpty'));
var mobx = require('mobx');
var app = require('firebase/app');
var storage = require('firebase/storage');
var axios = _interopDefault(require('axios'));
var jsep = _interopDefault(require('jsep'));
var moment = _interopDefault(require('moment'));

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) {
  try {
    var info = gen[key](arg);
    var value = info.value;
  } catch (error) {
    reject(error);
    return;
  }

  if (info.done) {
    resolve(value);
  } else {
    Promise.resolve(value).then(_next, _throw);
  }
}

function _asyncToGenerator(fn) {
  return function () {
    var self = this,
        args = arguments;
    return new Promise(function (resolve, reject) {
      var gen = fn.apply(self, args);

      function _next(value) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value);
      }

      function _throw(err) {
        asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err);
      }

      _next(undefined);
    });
  };
}

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;

  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }

  return target;
}

var SFProText = "85b4043974a2a3be.otf";

var body1 = {
  color: function color(_ref) {
    var palette = _ref.theme.palette;
    return palette.black;
  },
  fontSize: '16px',
  lineHeight: '24px',
  fontWeight: 400,
  fontFamily: 'SF Pro Text',
  margin: 0
};

var h3 = /*#__PURE__*/_extends({}, body1, {
  fontWeight: 600,
  color: function color(_ref2) {
    var palette = _ref2.theme.palette;
    return palette.dark_black;
  }
});

var h4 = /*#__PURE__*/_extends({}, h3, {
  fontSize: '14px',
  lineHeight: '18px'
});

var h2 = {
  fontWeight: 600,
  margin: 0,
  fontFamily: 'SF Pro Text',
  fontSize: '22px',
  lineHeight: '30px',
  color: function color(_ref3) {
    var palette = _ref3.theme.palette;
    return palette.dark_black;
  }
};
var label = {
  margin: 0,
  fontFamily: 'SF Pro Text',
  fontWeight: 400,
  fontSize: '12px',
  lineHeight: '18px',
  color: function color(_ref4) {
    var palette = _ref4.theme.palette;
    return palette.dark_black;
  }
};
var title = {
  padding: 0,
  fontWeight: 600,
  fontSize: 16,
  fontFamily: 'SF Pro Text',
  lineHeight: '24px',
  textAlign: 'center',
  letterSpacing: '-0.0024em',
  margin: 0
};

var bigTitle = /*#__PURE__*/_extends({}, title, {
  fontSize: 34,
  lineHeight: '40px'
});

var useStyles = /*#__PURE__*/reactJss.createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  body1: body1,
  h2: h2,
  h3: h3,
  h4: h4,
  label: label,
  title: title,
  bigTitle: bigTitle
});

var palette = {
  boxShadow: '0 0 0 0.2rem rgb(145 156 248 / 50%)',
  primary: '#4B46EC',
  primary_dark: '#1d17ef',
  light: '#F0F0FF',
  light_hover: '#d9d9f7',
  black: '#121620',
  dark_black: '#232323',
  white: '#ffffff',
  extra_light: '#dee5f9',
  gray: '#f0f0f0',
  light_gray: '#c7c7c7',
  gray_200: '#8e8e93',
  gray_300: '#C5C5D1',
  error: '#FF5758',
  gray_400: '#E0E3EB',
  gray_500: '#868C99'
};

var font = {
  font16Medium: {
    fontSize: '16px',
    fontWeight: 400,
    lineHeight: '24px'
  },
  font16Bold: {
    fontSize: '16px',
    fontWeight: 600,
    lineHeight: '24px'
  },
  font32Medium: {
    fontSize: '32px',
    fontWeight: 400
  },
  font24Medium: {
    fontSize: '24px',
    fontWeight: 400
  },
  font20Medium: {
    fontSize: '20px',
    lineHeight: '26px'
  },
  font18Medium: {
    fontSize: '18px'
  },
  font14Medium: {
    fontSize: '14px',
    lineHeight: '18px'
  },
  font12Medium: {
    fontSize: '12px',
    lineHeight: '16px'
  }
};

// node modules
var defaultTheme = {
  palette: palette,
  font: font
};
var ThemeContext = /*#__PURE__*/React.createContext(defaultTheme);
var theming = /*#__PURE__*/reactJss.createTheming(ThemeContext);

var Typography = function Typography(_ref) {
  var className = _ref.className,
      variant = _ref.variant,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "variant", "children"]);

  var classes = useStyles({
    theme: theming.useTheme()
  });
  var variantClassName = classes[variant] ? classes[variant] : classes.body1;
  var typClassName = variantClassName + " " + className;
  return React__default.createElement("p", Object.assign({
    className: typClassName
  }, otherProps), children);
};

// node modules
var useStyles$1 = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    outline: 'none',
    border: 'none',
    background: 'none',
    fontSize: 16,
    padding: '18px',
    cursor: 'pointer',
    transition: 'all .3s ease',
    minWidth: 150,
    '@media (max-width: 365px)': {
      minWidth: 136
    },
    position: 'relative',
    '-webkit-tap-highlight-color': 'rgba(0,0,0,0)',
    '&>p': {
      lineHeight: '20px'
    }
  },
  disabledClass: {
    cursor: 'not-allowed',
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return [[palette.black], '!important'];
    },
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return [[palette.light_gray], '!important'];
    }
  },
  centeredLabel: {
    textAlign: 'center',
    width: '100%'
  },
  loader: {
    width: 20,
    height: 20
  }
});

var useDelayAction = function useDelayAction() {
  var _useState = React.useState(true),
      actionAvailable = _useState[0],
      setActionAvailability = _useState[1];

  return {
    availabilityWatcher: function availabilityWatcher(action, delay) {
      if (!actionAvailable) return;
      action();
      setActionAvailability(false);
      setTimeout(function () {
        return setActionAvailability(true);
      }, delay);
    }
  };
};

var img = "data:image/svg+xml,%3csvg xmlns='http://www.w3.org/2000/svg' xmlns:xlink='http://www.w3.org/1999/xlink' style='margin: auto%3b display: block%3b' width='118px' height='118px' viewBox='0 0 100 100' preserveAspectRatio='xMidYMid'%3e %3ccircle cx='92' cy='50' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.9090909090909091s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.9090909090909091s'%3e%3c/animate%3e %3c/circle%3e%3ccircle cx='85.33264837890961' cy='72.7069143331351' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.8181818181818182s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.8181818181818182s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='67.44743054607923' cy='88.20454380488977' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.7272727272727273s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.7272727272727273s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='44.02277679252203' cy='91.57250055899918' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.6363636363636364s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.6363636363636364s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='22.49584917429803' cy='81.74148212287885' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.5454545454545454s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.5454545454545454s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='9.701295108191111' cy='61.83276738734005' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.45454545454545453s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.45454545454545453s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='9.701295108191104' cy='38.167232612659966' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.36363636363636365s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.36363636363636365s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='22.495849174298023' cy='18.258517877121157' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.2727272727272727s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.2727272727272727s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='44.02277679252202' cy='8.427499441000826' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.18181818181818182s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.18181818181818182s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='67.44743054607922' cy='11.79545619511022' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='-0.09090909090909091s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='-0.09090909090909091s'%3e%3c/animate%3e%3c/circle%3e%3ccircle cx='85.33264837890961' cy='27.293085666864908' fill='%23fbfbfb' r='11'%3e %3canimate attributeName='r' values='6.6%3b6.6%3b11%3b6.6%3b6.6' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' repeatCount='indefinite' begin='0s'%3e%3c/animate%3e %3canimate attributeName='fill' values='%23fbfbfb%3b%23fbfbfb%3bwhite%3b%23fbfbfb%3b%23fbfbfb' repeatCount='indefinite' times='0%3b0.1%3b0.2%3b0.3%3b1' dur='1s' begin='0s'%3e%3c/animate%3e%3c/circle%3e%3c/svg%3e";

var SimpleButton = function SimpleButton(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      label = _ref.label,
      width = _ref.width,
      disabled = _ref.disabled,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      onClick = _ref.onClick,
      children = _ref.children,
      delayNextClick = _ref.delayNextClick,
      loading = _ref.loading,
      _ref$textTransform = _ref.textTransform,
      textTransform = _ref$textTransform === void 0 ? 'none' : _ref$textTransform,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "label", "width", "disabled", "centered", "onClick", "children", "delayNextClick", "loading", "textTransform"]);

  var _useStyles = useStyles$1({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      disabledClass = _useStyles.disabledClass,
      centeredLabel = _useStyles.centeredLabel,
      loader = _useStyles.loader;

  var btnClassName = root + " " + className + " " + (disabled && disabledClass);

  var _useDelayAction = useDelayAction(),
      availabilityWatcher = _useDelayAction.availabilityWatcher;

  var handleClick = function handleClick() {
    if (disabled || loading) return;
    if (onClick) availabilityWatcher(onClick, delayNextClick || 500);
  };

  return React__default.createElement("button", Object.assign({
    onClick: handleClick,
    style: {
      width: width,
      textTransform: textTransform
    },
    className: btnClassName
  }, otherProps), loading ? React__default.createElement("img", {
    src: img,
    className: loader,
    alt: "loader"
  }) : React__default.createElement(React__default.Fragment, null, label ? React__default.createElement(Typography, {
    variant: "title",
    className: centered ? centeredLabel : ''
  }, label) : null, children));
};

var DEFAULT_MULTI_CLICK_PROTECTOR_DELAY = 350;

var timer = null;
var useMultiClickProtector = function useMultiClickProtector(delay) {
  if (delay === void 0) {
    delay = DEFAULT_MULTI_CLICK_PROTECTOR_DELAY;
  }

  React.useEffect(function () {
    return function () {
      clearTimeout(timer);
      timer = null;
    };
  }, []);

  var handleMultiClickProtector = function handleMultiClickProtector(cb) {
    return function () {
      if (timer) return;
      timer = setTimeout(function () {
        timer = null;
      }, delay);
      cb();
    };
  };

  return {
    handleMultiClickProtector: handleMultiClickProtector
  };
};

// node modules
var useStyles$2 = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    borderRadius: '.5rem',
    transition: 'background-color .3s, color .3s',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    },
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.black;
    }
  },
  rootSelected: {
    background: function background(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.primary;
    },
    color: function color() {
      return "#ffffff";
    },
    '&:active': {
      boxShadow: function boxShadow(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.boxShadow;
      }
    }
  }
});

var SelectButton = function SelectButton(_ref) {
  var className = _ref.className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      children = _ref.children,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      _ref$multiClickProtec = _ref.multiClickProtector,
      multiClickProtector = _ref$multiClickProtec === void 0 ? true : _ref$multiClickProtec,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$multiClickProtec2 = _ref.multiClickProtectorDelay,
      multiClickProtectorDelay = _ref$multiClickProtec2 === void 0 ? DEFAULT_MULTI_CLICK_PROTECTOR_DELAY : _ref$multiClickProtec2,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "selected", "children", "centered", "multiClickProtector", "onClick", "multiClickProtectorDelay"]);

  var _useStyles = useStyles$2({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      rootSelected = _useStyles.rootSelected;

  var _useMultiClickProtect = useMultiClickProtector(multiClickProtectorDelay),
      handleMultiClickProtector = _useMultiClickProtect.handleMultiClickProtector;

  var selectedClass = selected ? rootSelected : '';
  var selectBtnClass = root + " " + selectedClass + " " + className;
  var handleClick = multiClickProtector ? handleMultiClickProtector(onClick) : onClick;
  return React__default.createElement(SimpleButton, Object.assign({
    onClick: handleClick,
    centered: centered,
    className: selectBtnClass
  }, otherProps), children);
};

var img$1 = "data:image/svg+xml,%3csvg viewBox='0 0 18 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cstyle%3e path %7b color: %23066fde %7d %3c/style%3e %3cpath d='M17 1.67407L6 12.6741L1 7.67407' stroke='currentColor' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var alignment = {
  center: {
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center'
  },
  betweenCenter: {
    display: 'flex',
    justifyContent: 'space-between',
    alignItems: 'center'
  },
  rowCenter: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  }
};

var useStyles$3 = /*#__PURE__*/reactJss.createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.betweenCenter),
  checkWrapper: /*#__PURE__*/_extends({
    borderRadius: '50%'
  }, alignment.center, {
    marginLeft: 8,
    minWidth: 24,
    width: 24,
    height: 24,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.white;
    },
    position: 'absolute',
    right: '18px'
  }),
  checkIconCl: {
    width: 12
  },
  childrenStyle: {
    paddingRight: '32px'
  },
  centeredChildren: {
    width: '100%',
    paddingLeft: '32px'
  }
});

var CheckButton = function CheckButton(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["label", "className", "selected", "centered", "children"]);

  var _useStyles = useStyles$3({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      checkWrapper = _useStyles.checkWrapper,
      checkIconCl = _useStyles.checkIconCl,
      childrenStyle = _useStyles.childrenStyle,
      centeredChildren = _useStyles.centeredChildren;

  var checkBtnClass = root + " " + className;
  return React__default.createElement(SelectButton, Object.assign({
    centered: centered,
    selected: selected,
    label: '',
    className: checkBtnClass
  }, otherProps), React__default.createElement("div", {
    className: childrenStyle + " " + (centered ? centeredChildren : '')
  }, children || label), React__default.createElement("div", {
    className: checkWrapper
  }, selected && React__default.createElement("img", {
    className: checkIconCl,
    src: img$1,
    alt: ""
  })));
};

var img$2 = "data:image/svg+xml,%3csvg viewBox='0 0 18 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cstyle%3e path %7b color: white %7d %3c/style%3e %3cpath d='M17 1.67407L6 12.6741L1 7.67407' stroke='currentColor' stroke-width='2' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

var useStyles$4 = /*#__PURE__*/reactJss.createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.betweenCenter),
  checkWrapper: /*#__PURE__*/_extends({
    borderRadius: '50%'
  }, alignment.center, {
    marginLeft: 8,
    minWidth: 24,
    width: 24,
    height: 24,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    },
    position: 'absolute',
    right: '18px'
  }),
  checkIconCl: {
    width: 12
  },
  childrenStyle: {
    paddingRight: '32px'
  },
  centeredChildren: {
    width: '100%',
    paddingLeft: '32px'
  },
  activeCheckWrapper: {
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.primary;
    }
  }
});

var CheckButtonPrimary = function CheckButtonPrimary(_ref) {
  var _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$selected = _ref.selected,
      selected = _ref$selected === void 0 ? false : _ref$selected,
      _ref$centered = _ref.centered,
      centered = _ref$centered === void 0 ? false : _ref$centered,
      _ref$iconColor = _ref.iconColor,
      iconColor = _ref$iconColor === void 0 ? 'white' : _ref$iconColor,
      children = _ref.children,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["label", "className", "selected", "centered", "iconColor", "children"]);

  var _useStyles = useStyles$4({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      checkWrapper = _useStyles.checkWrapper,
      checkIconCl = _useStyles.checkIconCl,
      childrenStyle = _useStyles.childrenStyle,
      centeredChildren = _useStyles.centeredChildren,
      activeCheckWrapper = _useStyles.activeCheckWrapper;

  var checkBtnClass = root + " " + className;
  return React__default.createElement(SelectButton, Object.assign({
    centered: centered,
    selected: selected,
    label: '',
    className: checkBtnClass
  }, otherProps), React__default.createElement("div", {
    className: childrenStyle + " " + (centered ? centeredChildren : '')
  }, children || label), React__default.createElement("div", {
    className: checkWrapper + " " + (selected ? activeCheckWrapper : '')
  }, selected && React__default.createElement("img", {
    className: checkIconCl,
    src: iconColor === 'blue' ? img$1 : img$2,
    alt: ""
  })));
};

// node modules
var useStyles$5 = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    borderRadius: '2em',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.primary;
    },
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.light;
    },
    transition: 'background .3s, color .3s, box-shadow 2s',
    '&:hover': {
      background: function background(_ref3) {
        var palette = _ref3.theme.palette;
        return palette.primary_dark;
      }
    },
    '&:active': {
      boxShadow: function boxShadow(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.boxShadow;
      }
    }
  }
});

var PrimaryButton = function PrimaryButton(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$label = _ref.label,
      label = _ref$label === void 0 ? '' : _ref$label,
      children = _ref.children,
      _ref$multiClickProtec = _ref.multiClickProtector,
      multiClickProtector = _ref$multiClickProtec === void 0 ? true : _ref$multiClickProtec,
      _ref$multiClickProtec2 = _ref.multiClickProtectorDelay,
      multiClickProtectorDelay = _ref$multiClickProtec2 === void 0 ? DEFAULT_MULTI_CLICK_PROTECTOR_DELAY : _ref$multiClickProtec2,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["className", "label", "children", "multiClickProtector", "multiClickProtectorDelay", "onClick"]);

  var _useMultiClickProtect = useMultiClickProtector(multiClickProtectorDelay),
      handleMultiClickProtector = _useMultiClickProtect.handleMultiClickProtector;

  var theme = theming.useTheme();

  var _useStyles = useStyles$5({
    theme: theme
  }),
      root = _useStyles.root;

  var primaryBtnClassName = root + " " + className;
  var handleClick = multiClickProtector ? handleMultiClickProtector(onClick) : onClick;
  return React__default.createElement(SimpleButton, Object.assign({
    onClick: handleClick,
    className: primaryBtnClassName,
    label: label
  }, otherProps), children);
};

// node modules
var useStyles$6 = /*#__PURE__*/reactJss.createUseStyles({
  block: {
    position: 'fixed',
    width: '100%',
    left: 0,
    top: 0,
    padding: '0.5rem 2rem',
    boxSizing: 'border-box',
    display: 'flex',
    justifyContent: 'flex-end',
    alignItems: 'center',
    zIndex: 1,
    backgroundColor: '#066FDE',
    lineHeight: '1.5rem',
    fontSize: '1rem',
    fontStyle: 'normal',
    opacity: 0.8
  },
  typography: {
    textOverflow: 'ellipsis',
    maxWidth: '300px',
    overflow: 'hidden',
    color: 'white',
    lineHeight: '1.5rem',
    fontSize: '1rem',
    fontStyle: 'normal',
    fontWeight: 700
  },
  imgWrapper: {
    width: '2rem',
    height: '2rem',
    color: '#066FDE',
    marginLeft: '.75rem',
    borderRadius: '50%',
    backgroundColor: '#fff',
    display: 'flex',
    alignItems: 'center',
    justifyContent: 'center',
    fontWeight: 600,
    textTransform: 'uppercase'
  }
});

// node modules
var Header = function Header(_ref) {
  var img = _ref.img,
      label = _ref.label;

  var _useStyles = useStyles$6(),
      block = _useStyles.block,
      typography = _useStyles.typography,
      imgWrapper = _useStyles.imgWrapper;

  return React__default.createElement("div", {
    className: block
  }, React__default.createElement(Typography, {
    variant: "h4",
    className: typography
  }, label), img ? typeof img === 'string' ? React__default.createElement("img", {
    src: img,
    className: imgWrapper
  }) : {
    img: img
  } : React__default.createElement("div", {
    className: imgWrapper
  }, typeof label === 'string' ? label[0] : ''));
};

var img$3 = "data:image/svg+xml,%3csvg width='23' height='14' viewBox='0 0 23 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M21.6161 0.450918C20.9883 -0.211053 20.1996 -0.10737 19.5366 0.52202L8.75873 10.8412L3.39961 5.42612C2.76194 4.77188 1.68996 4.33711 1.03516 4.97487C0.380914 5.61198 0.764157 6.5081 1.40128 7.16234L7.57427 13.5001C7.89776 13.8325 8.32769 14 8.75873 14C9.1677 14 9.57667 13.849 9.8969 13.5464L21.6366 2.41304C22.2991 1.78468 22.2449 1.11345 21.6161 0.450918Z' fill='%23202B47'/%3e%3c/svg%3e";

var img$4 = "data:image/svg+xml,%3csvg width='17' height='16' viewBox='0 0 17 16' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M0.607422 1.77734L2.3852 -0.000434061L16.6074 14.2218L14.8296 15.9996L0.607422 1.77734Z' fill='%23202B47'/%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M16.6074 1.77734L14.8296 -0.000434061L0.607422 14.2218L2.3852 15.9996L16.6074 1.77734Z' fill='%23202B47'/%3e%3c/svg%3e";

var useStyles$7 = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: /*#__PURE__*/_extends({}, alignment.center, {
    border: function border(_ref) {
      var palette = _ref.theme.palette;
      return "2px solid " + palette.gray_300;
    },
    borderRadius: 10,
    width: 160,
    paddingBottom: 15,
    paddingTop: 39,
    boxSizing: 'border-box'
  }),
  content: /*#__PURE__*/_extends({}, alignment.rowCenter, {
    width: '100%'
  }),
  icon: {
    marginTop: 12,
    width: 23
  },
  btn: {
    minWidth: 'auto',
    width: 'calc(100% - 28px)',
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.gray_400;
    },
    color: function color(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.gray_500;
    },
    marginTop: 20,
    borderRadius: '10px',
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    },
    '&:active': {
      background: function background(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.primary;
      },
      color: function color(_ref5) {
        var palette = _ref5.theme.palette;
        return palette.light;
      }
    }
  },
  activeBtn: {
    background: function background(_ref6) {
      var palette = _ref6.theme.palette;
      return palette.primary;
    },
    color: function color(_ref7) {
      var palette = _ref7.theme.palette;
      return palette.light;
    },
    '&:active': {
      background: function background(_ref8) {
        var palette = _ref8.theme.palette;
        return palette.gray_400;
      },
      color: function color(_ref9) {
        var palette = _ref9.theme.palette;
        return palette.gray_500;
      }
    }
  },
  activeImg: {
    width: 16
  },
  typClass: {
    marginTop: 12,
    color: function color(_ref10) {
      var palette = _ref10.theme.palette;
      return palette.gray_500;
    }
  },
  activeTotalSavingTitle: {
    fontSize: 22,
    lineHeight: '30px'
  },
  priceWrapperActive: {
    fontWeight: 600
  },
  priceWrapper: {
    display: 'flex',
    alignItems: 'flex-end',
    fontSize: 28,
    lineHeight: '34px'
  },
  wrapperActive: {
    borderColor: function borderColor(_ref11) {
      var palette = _ref11.theme.palette;
      return palette.primary;
    },
    position: 'relative'
  },
  activePopUp: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    top: -20,
    left: -2,
    borderTopLeftRadius: '10px',
    borderTopRightRadius: '10px',
    lineHeight: '14px',
    fontWeight: 600,
    background: function background(_ref12) {
      var palette = _ref12.theme.palette;
      return palette.primary;
    },
    height: 32,
    width: 'calc(100% + 4px)',
    color: function color(_ref13) {
      var palette = _ref13.theme.palette;
      return palette.white;
    }
  }),
  priceTextStyle: {
    fontSize: '16px',
    lineHeight: '24px',
    fontWeight: 600
  }
});

// node modules
var PriceBlock = function PriceBlock(_ref) {
  var totalSavingText = _ref.totalSavingText,
      btnLabel = _ref.btnLabel,
      active = _ref.active,
      price = _ref.price,
      term = _ref.term,
      priceText = _ref.priceText,
      savingPrice = _ref.savingPrice,
      trialTitle = _ref.trialTitle,
      _ref$currency = _ref.currency,
      currency = _ref$currency === void 0 ? '$' : _ref$currency,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$trialIcon = _ref.trialIcon,
      trialIcon = _ref$trialIcon === void 0 ? true : _ref$trialIcon;

  var _useStyles = useStyles$7({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      icon = _useStyles.icon,
      content = _useStyles.content,
      btn = _useStyles.btn,
      activeBtn = _useStyles.activeBtn,
      activeImg = _useStyles.activeImg,
      typClass = _useStyles.typClass,
      priceWrapper = _useStyles.priceWrapper,
      priceWrapperActive = _useStyles.priceWrapperActive,
      wrapperActive = _useStyles.wrapperActive,
      activePopUp = _useStyles.activePopUp,
      priceTextStyle = _useStyles.priceTextStyle,
      activeTotalSavingTitle = _useStyles.activeTotalSavingTitle;

  return React__default.createElement("div", {
    className: wrapper + " " + (active ? wrapperActive : '') + " " + className
  }, React__default.createElement("div", {
    className: content
  }, React__default.createElement(Typography, {
    className: priceWrapper + " " + (active ? priceWrapperActive : ''),
    variant: "body1"
  }, currency, price, term && React__default.createElement(Typography, {
    variant: "body2"
  }, "/", term)), priceText && React__default.createElement(Typography, {
    className: priceTextStyle,
    variant: "body2"
  }, " ", priceText), React__default.createElement(Typography, {
    className: typClass,
    variant: "h4"
  }, totalSavingText || 'Total saving'), React__default.createElement(Typography, {
    className: active ? activeTotalSavingTitle : '',
    variant: "title"
  }, currency, savingPrice), React__default.createElement(Typography, {
    className: typClass,
    variant: "h4"
  }, trialTitle), trialIcon ? React__default.createElement("img", {
    className: icon + " " + (active ? activeImg : ''),
    src: active ? img$4 : img$3,
    alt: ""
  }) : React__default.createElement(Typography, {
    className: priceTextStyle,
    variant: "body2"
  }, " ", active ? 'no' : 'yes'), React__default.createElement(SimpleButton, {
    onClick: onClick,
    className: btn + " " + (active ? activeBtn : ''),
    label: btnLabel
  })), active && React__default.createElement(Typography, {
    className: activePopUp,
    variant: "label"
  }, "POPULAR"));
};

var useStyles$8 = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: /*#__PURE__*/_extends({}, alignment.center, {
    border: function border(_ref) {
      var palette = _ref.theme.palette;
      return "2px solid " + palette.gray_300;
    },
    borderRadius: 10,
    width: 160,
    boxSizing: 'border-box',
    padding: '16px 12px',
    marginRight: '3.5px',
    '& p': {
      '&:first-child': {
        fontSize: '22px',
        fontWeight: '600',
        lineHeight: '24px'
      },
      '&:last-child': {
        fontSize: '16px',
        fontWeight: '600',
        lineHeight: '24px',
        margin: 0
      }
    }
  }),
  content: /*#__PURE__*/_extends({}, alignment.rowCenter, {
    width: '100%'
  }),
  icon: {
    marginTop: 12,
    width: 23
  },
  btn: {
    minWidth: 'auto',
    width: '100%',
    background: '#f0f0f0',
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.primary;
    },
    marginTop: 20,
    borderRadius: '10px',
    height: '56px',
    padding: 0,
    '& p': {
      fontSize: 14,
      lineHeight: '18px'
    },
    '&:active': {
      background: function background(_ref3) {
        var palette = _ref3.theme.palette;
        return palette.primary;
      },
      color: function color(_ref4) {
        var palette = _ref4.theme.palette;
        return palette.light;
      }
    }
  },
  activeBtn: {
    background: function background(_ref5) {
      var palette = _ref5.theme.palette;
      return palette.primary;
    },
    color: function color(_ref6) {
      var palette = _ref6.theme.palette;
      return palette.light;
    },
    '&:active': {
      background: function background(_ref7) {
        var palette = _ref7.theme.palette;
        return palette.gray_400;
      },
      color: function color(_ref8) {
        var palette = _ref8.theme.palette;
        return palette.gray_500;
      }
    }
  },
  activeImg: {
    width: 16
  },
  typClass: {
    marginTop: 12,
    color: function color(_ref9) {
      var palette = _ref9.theme.palette;
      return palette.gray_500;
    }
  },
  activeTotalSavingTitle: {
    fontSize: 22,
    lineHeight: '30px'
  },
  priceWrapperActive: {
    fontWeight: 600
  },
  priceWrapper: {
    display: 'flex',
    alignItems: 'flex-end',
    fontSize: 28,
    lineHeight: '34px'
  },
  wrapperActive: {
    borderColor: function borderColor(_ref10) {
      var palette = _ref10.theme.palette;
      return palette.primary;
    },
    position: 'relative',
    borderRadius: 0,
    borderBottomRightRadius: '10px',
    borderBottomLeftRadius: '10px'
  },
  activePopUp: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    top: -33,
    left: -2,
    borderTopLeftRadius: '10px',
    borderTopRightRadius: '10px',
    lineHeight: '14px',
    fontSize: '12px !important',
    fontWeight: 600,
    background: function background(_ref11) {
      var palette = _ref11.theme.palette;
      return palette.primary;
    },
    height: 32,
    width: 'calc(100% + 4px)',
    color: function color(_ref12) {
      var palette = _ref12.theme.palette;
      return palette.white;
    }
  }),
  priceTextStyle: {
    fontSize: '16px',
    lineHeight: '24px',
    fontWeight: 600
  }
});

// node modules
var PriceBlockHint = function PriceBlockHint(_ref) {
  var btnLabel = _ref.btnLabel,
      active = _ref.active,
      price = _ref.price,
      term = _ref.term,
      priceText = _ref.priceText,
      savingPrice = _ref.savingPrice,
      trialTitle = _ref.trialTitle,
      _ref$currency = _ref.currency,
      currency = _ref$currency === void 0 ? '$' : _ref$currency,
      _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$onClick = _ref.onClick,
      onClick = _ref$onClick === void 0 ? function () {} : _ref$onClick,
      _ref$trialIcon = _ref.trialIcon,
      trialIcon = _ref$trialIcon === void 0 ? true : _ref$trialIcon;

  var _useStyles = useStyles$8({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      icon = _useStyles.icon,
      content = _useStyles.content,
      btn = _useStyles.btn,
      activeBtn = _useStyles.activeBtn,
      activeImg = _useStyles.activeImg,
      typClass = _useStyles.typClass,
      priceWrapper = _useStyles.priceWrapper,
      priceWrapperActive = _useStyles.priceWrapperActive,
      wrapperActive = _useStyles.wrapperActive,
      activePopUp = _useStyles.activePopUp,
      priceTextStyle = _useStyles.priceTextStyle;

  return React__default.createElement("div", {
    className: wrapper + " " + (active ? wrapperActive : '') + " " + className
  }, React__default.createElement("div", {
    className: content
  }, React__default.createElement(Typography, {
    className: priceWrapper + " " + (active ? priceWrapperActive : ''),
    variant: "body1"
  }, currency, price, term && React__default.createElement(Typography, {
    variant: "body2"
  }, "/", term)), priceText && React__default.createElement(Typography, {
    className: priceTextStyle,
    variant: "body2"
  }, " ", priceText), React__default.createElement(Typography, {
    className: typClass,
    variant: "h4"
  }, "Total savings"), React__default.createElement(Typography, {
    variant: "title"
  }, currency, savingPrice), React__default.createElement(Typography, {
    className: typClass,
    variant: "h4"
  }, trialTitle), trialIcon ? React__default.createElement("img", {
    className: icon + " " + (active ? activeImg : ''),
    src: active ? img$4 : img$3,
    alt: ""
  }) : React__default.createElement(Typography, {
    className: priceTextStyle,
    variant: "body2"
  }, " ", active ? 'no' : 'yes'), React__default.createElement(SimpleButton, {
    onClick: onClick,
    className: btn + " " + (active ? activeBtn : ''),
    label: btnLabel
  })), active && React__default.createElement(Typography, {
    className: activePopUp,
    variant: "label"
  }, "POPULAR"));
};

var useStyles$9 = /*#__PURE__*/reactJss.createUseStyles({
  root: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'fixed',
    top: 0,
    left: 0,
    right: 0,
    bottom: 0,
    background: 'rgba(85, 84, 85, 0.8);',
    zIndex: 1
  })
});

// node modules
var DialogContent = function DialogContent(_ref) {
  var children = _ref.children,
      _ref$open = _ref.open,
      open = _ref$open === void 0 ? false : _ref$open,
      _ref$rootClassName = _ref.rootClassName,
      rootClassName = _ref$rootClassName === void 0 ? '' : _ref$rootClassName;

  var _useStyles = useStyles$9(),
      root = _useStyles.root;

  return open ? React__default.createElement("div", {
    className: root + " " + rootClassName
  }, children, " ") : null;
};

// node modules
var ModalWindow = function ModalWindow(props) {
  return React__default.createElement(DialogContent, Object.assign({}, props));
};

var replaceLinks = function replaceLinks(str) {
  return str.replace(/\[([\s\S]*?)]/g, function (_, key) {
    var _key$split = key.split('|'),
        link = _key$split[0],
        linkName = _key$split[1];

    if (link && linkName) {
      return "<a target=\"_blank\" href=\"" + link.trim() + "\">" + linkName.trim() + "</a>";
    }

    return "[" + key + "]";
  });
};

var replaceTags = function replaceTags(_ref) {
  var symbol = _ref[0],
      tag = _ref[1];
  var regExp = new RegExp("\\" + symbol + "([\\s\\S]*?)\\" + symbol, 'g');
  return function (str) {
    return str.replace(regExp, "<" + tag + ">$1</" + tag + ">");
  };
};

// local files
var generateParser = function generateParser(options) {
  var parser = {};
  var tagWrappers = options.tagWrappers,
      brChanger = options.brChanger;

  if (tagWrappers) {
    if (typeof tagWrappers[0] === 'string') {
      parser.tagChangers = [replaceTags(tagWrappers)];
    }

    if (typeof tagWrappers[0] === 'object') {
      // @ts-ignore
      parser.tagChangers = tagWrappers.map(function (wrapper) {
        return replaceTags(wrapper);
      });
    }
  }

  if (brChanger) {
    parser.brChanger = function (s) {
      return s.replace(/\n/g, '<br>');
    };
  }

  return parser;
};

var replaceVariables = function replaceVariables(someStr, options) {
  var variables = options.variables,
      localStorageMode = options.localStorageMode;
  return someStr.replace(/%_([\s\S]*?)_%/g, function (_, key) {
    if (localStorageMode) {
      var valueFromLocalStorage = localStorage.getItem(key);

      if (valueFromLocalStorage) {
        return valueFromLocalStorage;
      }
    }

    if (variables[key]) {
      return variables[key].toString();
    }

    return '_';
  });
};

var setCorrectUppercaseLowercase = function setCorrectUppercaseLowercase(str) {
  var newString = str.replace(/\^_([\s\S]*?)_\^/g, function (_, key) {
    var trimValue = key.trim();
    return trimValue.charAt(0).toLowerCase() + trimValue.slice(1);
  });
  newString = newString.replace(/\^-([\s\S]*?)-\^/g, function (_, key) {
    var trimValue = key.trim();
    return trimValue.charAt(0).toUpperCase() + trimValue.slice(1);
  });
  return newString;
};

// local files
var TextNormalizer = function TextNormalizer(str, options) {
  var newString = str;
  var parser = generateParser(options);
  newString = replaceVariables(newString, options);
  newString = replaceLinks(newString);
  newString = setCorrectUppercaseLowercase(newString);
  if (parser.tagChangers) parser.tagChangers.forEach(function (cb) {
    return newString = cb(newString);
  });
  if (parser.brChanger) newString = parser.brChanger(newString);
  return newString;
};

// node modules
var useStyles$a = /*#__PURE__*/reactJss.createUseStyles({
  imageWrapper: {},
  slideClass: {
    transition: 'opacity 1s',
    opacity: 0,
    overflow: 'hidden'
  },
  slideShowed: {
    opacity: 1
  },
  typ: {
    textAlign: 'left'
  }
});

// node modules

var waiting = function waiting(delay) {
  return new Promise(function (resolve) {
    setTimeout(resolve, delay);
  });
};

var ELEMENT_DELAY = 3000;
var TIMEOUT_DELAY = 1800;
var Slide = function Slide(_ref) {
  var handleNext = _ref.handleNext,
      content = _ref.content,
      rootSlideClass = _ref.rootSlideClass,
      color = _ref.color;

  var _useStyles = useStyles$a(),
      slideClass = _useStyles.slideClass,
      slideShowed = _useStyles.slideShowed,
      typ = _useStyles.typ,
      imageWrapper = _useStyles.imageWrapper;

  var _useState = React.useState(false),
      activeClass = _useState[0],
      setActiveClass = _useState[1];

  React.useEffect(function () {
    var delay = content.delay;
    waiting(delay || ELEMENT_DELAY).then(function () {
      setActiveClass(false);
      setTimeout(handleNext, TIMEOUT_DELAY);
    });
    setActiveClass(true);
  }, [content]);
  var className = slideClass + " " + rootSlideClass + " " + (activeClass ? slideShowed : '');
  return React__default.createElement("div", {
    className: className
  }, typeof content.value !== 'string' ? React__default.createElement("div", {
    className: imageWrapper
  }, content.value) : React__default.createElement(Typography, {
    style: {
      color: content.color || color || null
    },
    variant: content.variant || 'bigTitle',
    className: typ
  }, parser(TextNormalizer(content.value, {
    brChanger: true,
    localStorageMode: true
  }))));
};

// node modules
var useStyles$b = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    height: function height(_ref) {
      var _height = _ref.height,
          component = _ref.component;
      return component ? _height + "px" : "calc(" + _height + "px - 201px)";
    },
    overflow: 'hidden',
    padding: function padding(_ref2) {
      var component = _ref2.component;
      return component ? '0 32px 0 32px' : '201px 32px 0 32px';
    },
    display: function display(_ref3) {
      var component = _ref3.component;
      return component ? 'flex' : '';
    },
    alignItems: function alignItems(_ref4) {
      var component = _ref4.component;
      return component ? 'center' : '';
    },
    justifyContent: "center"
  },
  '@media (min-width: 1024px)': {
    root: {
      justifyContent: "center",
      display: 'flex'
    }
  }
});

// node modules
var SliderPage = function SliderPage(_ref) {
  var _ref$className = _ref.className,
      className = _ref$className === void 0 ? '' : _ref$className,
      _ref$elements = _ref.elements,
      elements = _ref$elements === void 0 ? [] : _ref$elements,
      onFinished = _ref.onFinished,
      background = _ref.background,
      textColor = _ref.textColor,
      slideClass = _ref.slideClass;

  var _useState = React.useState(0),
      activeSlide = _useState[0],
      setActiveSlide = _useState[1];

  var handleNextSlide = function handleNextSlide() {
    if (activeSlide + 1 === elements.length) {
      if (onFinished) {
        onFinished();
      }
    } else {
      setActiveSlide(activeSlide + 1);
    }
  };

  var _useStyles = useStyles$b({
    height: window.innerHeight,
    component: typeof elements[activeSlide].value !== 'string'
  }),
      root = _useStyles.root;

  return React__default.createElement("div", {
    className: root + " " + className,
    style: {
      background: background
    }
  }, React__default.createElement(Slide, {
    rootSlideClass: slideClass,
    color: textColor,
    handleNext: handleNextSlide,
    content: elements[activeSlide]
  }));
};

var img$5 = "data:image/svg+xml,%3csvg width='14' height='14' viewBox='0 0 14 14' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cpath fill-rule='evenodd' clip-rule='evenodd' d='M7 14C10.866 14 14 10.866 14 7C14 3.13401 10.866 0 7 0C3.13401 0 0 3.13401 0 7C0 10.866 3.13401 14 7 14ZM3.99988 4.7074L4.70698 4.00029L7.18201 6.47531L9.65703 4.00029L10.3641 4.7074L7.88911 7.18242L10.3638 9.65714L9.65673 10.3643L7.18201 7.88953L4.70728 10.3643L4.00017 9.65714L6.4749 7.18242L3.99988 4.7074Z' fill='%23C7C7C7'/%3e%3c/svg%3e";

var buttonInputCleanStyles = {
  border: 'none',
  outline: 'none',
  background: 'none'
};
var labelClassName = {
  color: function color(_ref) {
    var palette = _ref.theme.palette;
    return palette.black;
  },
  position: 'absolute',
  top: 0,
  left: 'calc(.75rem + 1px)',
  fontSize: '.875rem',
  lineHeight: '1.6rem',
  transform: 'translateY(calc(.75rem - 1px))',
  transition: 'all .2s ease',
  pointerEvents: 'none'
};
var activeLabelClassName = {
  color: function color(_ref2) {
    var palette = _ref2.theme.palette;
    return palette.gray_200;
  },
  fontSize: '.75rem',
  lineHeight: '1.8rem',
  transform: 'translateY(0)'
};
var labelWrapperRoot = {
  position: 'relative',
  border: function border(_ref3) {
    var palette = _ref3.theme.palette;
    return "1px solid " + palette.light_gray;
  },
  borderRadius: '.625rem',
  boxSizing: 'border-box'
};
var inputSelectCommonStylesProps = /*#__PURE__*/_extends({}, buttonInputCleanStyles, {
  all: 'unset',
  display: 'block',
  width: '100%',
  padding: '20px 0 5px .75rem',
  boxSizing: 'border-box',
  fontSize: '1rem',
  lineHeight: '1rem',
  borderRadius: '.625rem'
});
var disabled = {
  cursor: 'not-allowed',
  opacity: .4
};
var errorClass = {
  borderColor: function borderColor(_ref4) {
    var palette = _ref4.theme.palette;
    return palette.error;
  }
};

var ADORNMENT_WIDTH = 40;
var useStyles$c = /*#__PURE__*/reactJss.createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  root: /*#__PURE__*/_extends({}, labelWrapperRoot, {
    display: 'flex',
    paddingRight: 16
  }),
  input: /*#__PURE__*/_extends({}, inputSelectCommonStylesProps, {
    width: function width(_ref) {
      var adornmentEnd = _ref.adornmentEnd,
          adornmentStart = _ref.adornmentStart;
      return "calc(100% - " + (adornmentStart ? ADORNMENT_WIDTH : 0) + "px - " + (adornmentEnd ? ADORNMENT_WIDTH : 0) + "px)";
    },
    textAlign: 'left',
    fontFamily: 'SF Pro Text',
    '-webkit-tap-highlight-color': 'transparent'
  }),
  inputAdorned: {
    left: '30px !important'
  },
  inputAdornedActive: {
    left: '32px !important'
  },
  unlabeled: {
    padding: '12px 0 12px .75rem'
  },
  labelClass: /*#__PURE__*/_extends({}, labelClassName),
  active: /*#__PURE__*/_extends({}, activeLabelClassName),
  disabledClass: /*#__PURE__*/_extends({}, disabled),
  errorClass: /*#__PURE__*/_extends({}, errorClass),
  typeWrapper: /*#__PURE__*/_extends({}, alignment.center, {
    paddingLeft: 11,
    whiteSpace: 'nowrap',
    width: 40
  }),
  typeWrapperStart: /*#__PURE__*/_extends({}, alignment.center, {
    paddingRight: 11
  }),
  clearIconClass: {
    cursor: 'pointer',
    paddingLeft: 11
  }
});

var Input = function Input(_ref) {
  var _ref$error = _ref.error,
      error = _ref$error === void 0 ? false : _ref$error,
      _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'text' : _ref$type,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      labelClassName = _ref.labelClassName,
      rootClassName = _ref.rootClassName,
      onChange = _ref.onChange,
      label = _ref.label,
      value = _ref.value,
      onFocus = _ref.onFocus,
      onBlur = _ref.onBlur,
      adornmentEnd = _ref.adornmentEnd,
      adornmentStart = _ref.adornmentStart,
      closeIcon = _ref.closeIcon,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["error", "type", "disabled", "labelClassName", "rootClassName", "inputClassName", "onChange", "label", "value", "onFocus", "onBlur", "adornmentEnd", "adornmentStart", "closeIcon", "autoFocus"]);

  var _useStyles = useStyles$c({
    theme: theming.useTheme(),
    adornmentEnd: adornmentEnd,
    adornmentStart: adornmentStart
  }),
      root = _useStyles.root,
      labelClass = _useStyles.labelClass,
      active = _useStyles.active,
      input = _useStyles.input,
      unlabeled = _useStyles.unlabeled,
      disabledClass = _useStyles.disabledClass,
      errorClass = _useStyles.errorClass,
      typeWrapper = _useStyles.typeWrapper,
      clearIconClass = _useStyles.clearIconClass,
      inputAdorned = _useStyles.inputAdorned,
      inputAdornedActive = _useStyles.inputAdornedActive;

  var inputEl = React.useRef({});

  var _useState = React.useState(false),
      activeClass = _useState[0],
      setActiveClass = _useState[1];

  var handleFocus = function handleFocus(e) {
    if (disabled) return;
    setActiveClass(true);

    if (onFocus) {
      onFocus(e);
    }
  };

  var handleBlur = function handleBlur(e) {
    setActiveClass(!!e.target.value);

    if (onBlur) {
      onBlur(e);
    }
  };

  var handleChange = function handleChange(e) {
    if (onChange) {
      onChange(e);
    }
  };

  var handleClean = function handleClean() {
    var evt = new Event('change');
    var current = inputEl.current;
    current.value = '';

    var event = _extends({}, evt, {
      target: current,
      currentTarget: current
    });

    if (onChange) {
      onChange(event);
    }

    current.focus();
  };

  var adornmentClass = '';

  if (adornmentStart) {
    adornmentClass = inputAdorned + " " + (!!value || activeClass ? inputAdornedActive : '');
  }

  var classNameLabel = labelClass + " " + labelClassName + " " + (!!value || activeClass ? active : '') + " " + adornmentClass;
  var rootClass = root + " " + rootClassName + " " + (disabled ? disabledClass : '') + " " + (error ? errorClass : '');
  var inputClass = input + " " + (!label ? unlabeled : '');
  return React__default.createElement("div", {
    className: rootClass
  }, adornmentStart && React__default.createElement("div", {
    className: typeWrapper
  }, React__default.createElement(Typography, {
    variant: "body1"
  }, adornmentStart)), label && React__default.createElement(Typography, {
    variant: "body2",
    className: classNameLabel
  }, label), React__default.createElement("input", Object.assign({
    ref: inputEl,
    type: type,
    disabled: disabled,
    onBlur: handleBlur,
    onFocus: handleFocus,
    className: inputClass,
    value: value,
    onChange: handleChange
  }, otherProps)), adornmentEnd && React__default.createElement("div", {
    className: typeWrapper
  }, React__default.createElement(Typography, {
    variant: "body1"
  }, adornmentEnd)), closeIcon && value && React__default.createElement("img", {
    className: clearIconClass,
    onClick: handleClean,
    src: img$5,
    alt: ""
  }));
};

// node modules
var useStyles$d = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    position: 'relative',
    height: 48,
    borderRadius: '.5rem',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light_gray;
    }
  },
  text: {
    position: 'absolute',
    top: '50%',
    left: '50%',
    transform: 'translate(-50%, -50%)',
    color: function color(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    },
    zIndex: 1
  },
  childBar: {
    maxWidth: '100%',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    borderRadius: '.5rem',
    background: function background(_ref3) {
      var palette = _ref3.theme.palette;
      return palette.primary;
    },
    transition: 'width .3s'
  }
});

// node modules
var ProgressBar = function ProgressBar(_ref) {
  var percents = _ref.percents,
      className = _ref.className;

  var _useStyles = useStyles$d({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      childBar = _useStyles.childBar,
      text = _useStyles.text;

  var width = "calc(100% * " + percents / 100 + ")";
  return React__default.createElement("div", {
    className: wrapper + " " + className
  }, React__default.createElement("span", {
    className: text
  }, percents, " %"), React__default.createElement("div", {
    className: childBar,
    style: {
      width: width
    }
  }));
};

var useStyles$e = /*#__PURE__*/reactJss.createUseStyles({
  progressWrapper: {
    position: 'relative',
    height: 8,
    borderRadius: '1.875rem',
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.gray;
    }
  },
  progress: {
    maxWidth: '100%',
    position: 'absolute',
    left: 0,
    top: 0,
    height: '100%',
    borderRadius: '1.875rem',
    transition: 'width .3s'
  },
  counter: {
    minWidth: '50px',
    textAlign: 'right'
  },
  infoWrapper: /*#__PURE__*/_extends({
    marginBottom: 8
  }, alignment.betweenCenter)
});

// node modules
var ProgressBarThin = function ProgressBarThin(_ref) {
  var _ref$percents = _ref.percents,
      percents = _ref$percents === void 0 ? 0 : _ref$percents,
      _ref$color = _ref.color,
      color = _ref$color === void 0 ? palette.primary : _ref$color,
      _ref$completed = _ref.completed,
      completed = _ref$completed === void 0 ? true : _ref$completed,
      title = _ref.title,
      className = _ref.className;

  var _useStyles = useStyles$e({
    theme: theming.useTheme()
  }),
      progressWrapper = _useStyles.progressWrapper,
      progress = _useStyles.progress,
      infoWrapper = _useStyles.infoWrapper,
      counter = _useStyles.counter;

  var width = "calc(100% * " + percents / 100 + ")";
  var variant = completed ? 'body2' : 'h3';
  return React__default.createElement("div", {
    className: className
  }, React__default.createElement("div", {
    className: infoWrapper
  }, React__default.createElement(Typography, {
    variant: variant,
    style: {
      color: color
    }
  }, title), React__default.createElement(Typography, {
    className: counter,
    variant: variant,
    style: {
      color: color
    }
  }, percents, " %")), React__default.createElement("div", {
    className: progressWrapper
  }, React__default.createElement("div", {
    className: progress,
    style: {
      background: color,
      width: width
    }
  })));
};

// node modules
var getCorrectInput = function getCorrectInput(i, steps, percents) {
  if (!i) return '';
  if (i / steps * 100 <= percents) return React__default.createElement("img", {
    style: {
      width: 9
    },
    src: img$2,
    alt: ""
  });
  return i;
};
var getCorrectColor = function getCorrectColor(i, steps, percents, colors, backgroundColor) {
  if (i / steps * 100 <= percents) {
    return !colors[i - 1] ? colors[i] : colors[i - 1];
  }

  return backgroundColor || palette.gray_400;
};
var getIndexColorToTitle = function getIndexColorToTitle(correctPercents, steps, colors) {
  var index = Math.floor(steps * correctPercents / 100);

  if (index === colors.length) {
    index = index - 1;
  }

  return index;
};

var createUniqIdGenerator = function createUniqIdGenerator() {
  var number = 0;
  return function () {
    return "id--" + number++;
  };
};

var uniqIdGenerator = /*#__PURE__*/createUniqIdGenerator();

var img$6 = "data:image/svg+xml,%3csvg width='24' height='24' viewBox='0 0 24 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath fill-rule='evenodd' clip-rule='evenodd' d='M14.7071 17.7071C14.3166 18.0976 13.6834 18.0976 13.2929 17.7071L8.29289 12.7071C7.90237 12.3166 7.90237 11.6834 8.29289 11.2929L13.2929 6.29289C13.6834 5.90237 14.3166 5.90237 14.7071 6.29289C15.0976 6.68342 15.0976 7.31658 14.7071 7.70711L10.4142 12L14.7071 16.2929C15.0976 16.6834 15.0976 17.3166 14.7071 17.7071Z' fill='%23858DA5'/%3e%3c/svg%3e";

var useStyles$f = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    width: '100%',
    minWidth: 200,
    position: 'relative',
    height: 6,
    marginBottom: 17
  },
  cercle: /*#__PURE__*/_extends({
    fontFamily: 'SF Pro Display',
    position: 'absolute',
    top: '50%',
    transform: 'translate(-50%, -50%)',
    width: 16,
    height: 16,
    borderRadius: '50%'
  }, alignment.center, {
    fontSize: 11,
    paddingBottom: 2,
    boxSizing: 'border-box',
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.black;
    }
  }),
  bar: {
    position: 'absolute',
    top: '50%',
    transform: 'translate(0, -50%)',
    height: 8
  },
  coverBlock: /*#__PURE__*/_extends({
    position: 'absolute',
    top: '50%',
    transform: 'translate(0, -50%)',
    right: 0,
    width: '100%',
    height: 8
  }, alignment.center, {
    transition: 'width .3s',
    minWidth: 0
  }),
  thinBlock: {
    width: '100%',
    height: 6
  },
  root: {
    display: 'flex',
    flexDirection: 'column',
    alignItems: 'center'
  },
  paddingWrapper: {
    padding: '5px 8px 0',
    position: 'relative'
  },
  backBtn: {
    position: 'absolute',
    top: 25,
    left: -6
  },
  '@media screen and (min-width: 768px)': {
    backBtn: {
      position: 'absolute',
      top: 25,
      left: 0
    },
    cercle: {
      paddingBottom: 0
    }
  }
});

// node modules
var ProgressStepper = function ProgressStepper(_ref) {
  var steps = _ref.steps,
      colors = _ref.colors,
      _ref$percents = _ref.percents,
      percents = _ref$percents === void 0 ? 0 : _ref$percents,
      title = _ref.title,
      backgroundColor = _ref.backgroundColor,
      backButton = _ref.backButton,
      handleBack = _ref.handleBack,
      stepperHeight = _ref.stepperHeight;

  var _useStyles = useStyles$f({
    theme: theming.useTheme()
  }),
      wrapper = _useStyles.wrapper,
      cercle = _useStyles.cercle,
      bar = _useStyles.bar,
      coverBlock = _useStyles.coverBlock,
      thinBlock = _useStyles.thinBlock,
      root = _useStyles.root,
      backBtn = _useStyles.backBtn,
      paddingWrapper = _useStyles.paddingWrapper;

  var generatedArray = new Array(steps + 1).fill(true);
  var correctPercents = percents <= 0 || isNaN(percents) ? 1 : percents;
  correctPercents = correctPercents > 100 ? 100 : correctPercents;
  return React__default.createElement("div", {
    className: paddingWrapper
  }, React__default.createElement("div", {
    className: root
  }, React__default.createElement("div", {
    className: wrapper
  }, generatedArray.map(function (_, i) {
    return React__default.createElement(React.Fragment, {
      key: uniqIdGenerator()
    }, !!i && React__default.createElement("span", {
      style: {
        left: 0,
        width: "calc(" + i + "/" + steps + " * 100%)",
        background: colors[i - 1],
        zIndex: steps + 1 - i,
        height: stepperHeight
      },
      className: bar
    }), React__default.createElement("span", {
      style: {
        left: "calc(" + i + "/" + steps + " * 100%)",
        zIndex: generatedArray.length + 2,
        background: getCorrectColor(i, steps, percents, colors, backgroundColor),
        color: '#202B47'
      },
      className: cercle
    }, getCorrectInput(i, steps, correctPercents)));
  }), React__default.createElement("div", {
    style: {
      zIndex: generatedArray.length + 1,
      width: "calc(100% - " + correctPercents + "%)",
      background: backgroundColor || palette.white,
      height: stepperHeight
    },
    className: coverBlock
  }, React__default.createElement("div", {
    style: {
      background: backgroundColor || palette.gray_400,
      height: stepperHeight
    },
    className: thinBlock
  }))), React__default.createElement(Typography, {
    style: {
      color: colors[getIndexColorToTitle(correctPercents, steps, colors)]
    },
    variant: "h4"
  }, title), backButton && React__default.createElement("img", {
    className: backBtn,
    onClick: handleBack,
    src: img$6,
    alt: ""
  })));
};

var useStyles$g = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    minWidth: 200
  },
  tabWrapper: /*#__PURE__*/_extends({}, alignment.betweenCenter, {
    height: 32,
    padding: 2,
    borderRadius: 8,
    background: function background(_ref) {
      var palette = _ref.theme.palette;
      return palette.light;
    }
  }),
  activeBtn: {
    background: function background(_ref2) {
      var palette = _ref2.theme.palette;
      return palette.white;
    }
  },
  btn: {
    minWidth: 'auto',
    padding: 0,
    height: '100%',
    borderRadius: 8
  }
});

// node modules
var Tab = function Tab(_ref) {
  var list = _ref.list,
      _ref$activeTab = _ref.activeTab,
      activeTab = _ref$activeTab === void 0 ? 0 : _ref$activeTab,
      _ref$width = _ref.width,
      width = _ref$width === void 0 ? '100%' : _ref$width,
      _ref$contentClass = _ref.contentClass,
      contentClass = _ref$contentClass === void 0 ? '' : _ref$contentClass,
      _ref$tabWrapperClass = _ref.tabWrapperClass,
      tabWrapperClass = _ref$tabWrapperClass === void 0 ? '' : _ref$tabWrapperClass,
      _ref$tabClass = _ref.tabClass,
      tabClass = _ref$tabClass === void 0 ? '' : _ref$tabClass,
      tabs = _ref.tabs,
      onChange = _ref.onChange;

  var _useStyles = useStyles$g({
    theme: theming.useTheme()
  }),
      tabWrapper = _useStyles.tabWrapper,
      activeBtn = _useStyles.activeBtn,
      btn = _useStyles.btn,
      wrapper = _useStyles.wrapper;

  var _useState = React.useState(activeTab),
      currentTab = _useState[0],
      setCurrentTab = _useState[1];

  React.useEffect(function () {
    setCurrentTab(activeTab);
  }, [activeTab]);
  React.useEffect(function () {
    if (onChange) onChange(currentTab);
  }, [currentTab]);
  if (tabs != null && tabs.length) return React__default.createElement("div", {
    className: wrapper,
    style: {
      width: width
    }
  }, React__default.createElement("div", {
    className: tabWrapper + " " + tabWrapperClass
  }, tabs.map(function (title, i) {
    var className = (i === currentTab ? activeBtn : '') + " " + btn + " " + tabClass;
    return React__default.createElement(SimpleButton, {
      key: uniqIdGenerator(),
      className: className,
      width: "calc(100% / " + tabs.length + " )",
      onClick: function onClick() {
        return setCurrentTab(i);
      },
      label: React__default.createElement(Typography, {
        variant: "label"
      }, title)
    });
  })));
  return React__default.createElement("div", {
    className: wrapper,
    style: {
      width: width
    }
  }, React__default.createElement("div", {
    className: tabWrapper + " " + tabWrapperClass
  }, list.map(function (_ref2, i) {
    var title = _ref2.title;
    var className = (i === currentTab ? activeBtn : '') + " " + btn + " " + tabClass;
    return React__default.createElement(SimpleButton, {
      key: uniqIdGenerator(),
      className: className,
      width: "calc(100% / " + list.length + " )",
      onClick: function onClick() {
        return setCurrentTab(i);
      },
      label: React__default.createElement(Typography, {
        variant: "label"
      }, title)
    });
  })), React__default.createElement("div", {
    className: contentClass
  }, list[currentTab].Content));
};

function IsJsonString(str) {
  try {
    JSON.parse(str);
  } catch (e) {
    return false;
  }

  return true;
}

var UPDATE_STORAGE_EVENT = 'onStoreUpdated';

var createUpdateStorageCustomEvent = function createUpdateStorageCustomEvent(value, keyEvent) {
  return new CustomEvent(UPDATE_STORAGE_EVENT, {
    detail: {
      value: value,
      keyEvent: keyEvent
    }
  });
};

var getDefaultValue = function getDefaultValue(key, defaultValue) {
  var data = localStorage.getItem(key);

  if (data) {
    if (IsJsonString(data)) {
      return JSON.parse(data);
    } else {
      return data;
    }
  } else {
    return defaultValue;
  }
};

var useLocalStorage = function useLocalStorage(_ref) {
  var key = _ref.key,
      defaultValue = _ref.defaultValue;

  var _useState = React.useState(getDefaultValue(key, defaultValue)),
      pageValue = _useState[0],
      setPageValue = _useState[1];

  React.useEffect(function () {
    window.addEventListener(UPDATE_STORAGE_EVENT, function (e) {
      if (key === e.detail.keyEvent) {
        setPageValue(e.detail.value);
      }
    });
    return function () {
      window.removeEventListener(UPDATE_STORAGE_EVENT, function (e) {
        if (key === e.detail.keyEvent) {
          setPageValue(e.detail.value);
        }
      });
    };
  }, [key]);
  React.useEffect(function () {
    if (typeof pageValue === 'object') {
      localStorage.setItem(key, JSON.stringify(pageValue) || '');
    } else {
      localStorage.setItem(key, pageValue || '');
    }

    window.dispatchEvent(createUpdateStorageCustomEvent(pageValue, key));
  }, [pageValue, key]);
  return {
    pageValue: pageValue,
    setPageValue: setPageValue
  };
};

var HOME_ROUTE = "/";

var getLastVisitedPage = function getLastVisitedPage(availableRoutersList) {
  return availableRoutersList[availableRoutersList.length - 1];
};

var isNotStartedPageAndNotIncludeInList = function isNotStartedPageAndNotIncludeInList(availableRoutersList, pathname, startPage) {
  return !availableRoutersList.includes(pathname) && startPage.current.pathname !== pathname;
};

var useAccessPageChecking = function useAccessPageChecking() {
  var _useLocation = reactRouterDom.useLocation(),
      pathname = _useLocation.pathname;

  var startPage = React.useRef({
    pathname: pathname
  });

  var _useState = React.useState(false),
      routerAvailable = _useState[0],
      doRouterAvailable = _useState[1];

  var _useLocalStorage = useLocalStorage({
    key: "available_routes",
    defaultValue: ["/"]
  }),
      availableRoutersList = _useLocalStorage.pageValue,
      addAvailableRoute = _useLocalStorage.setPageValue;

  React.useEffect(function () {
    if (availableRoutersList != null && availableRoutersList.includes(pathname)) {
      doRouterAvailable(true);
    } else if (pathname === HOME_ROUTE && !(availableRoutersList != null && availableRoutersList.includes(pathname))) {
      addAvailableRoute([pathname]);
      doRouterAvailable(true);
    } else {
      window.location.pathname = getLastVisitedPage(availableRoutersList);
    }
  }, []);
  React.useEffect(function () {
    if (isNotStartedPageAndNotIncludeInList(availableRoutersList, pathname, startPage)) {
      addAvailableRoute([].concat(availableRoutersList, [pathname]));
    }
  }, [pathname]);
  return {
    routerAvailable: routerAvailable
  };
};

// node modules
var useStyles$h = /*#__PURE__*/reactJss.createUseStyles({
  enter: {
    opacity: 0,
    transform: 'translateX(20px)'
  },
  enterActive: {
    opacity: 1,
    transform: 'translateX(0)',
    transition: function transition(_ref) {
      var timeout = _ref.theme.timeout;
      return "opacity " + timeout + "ms, transform " + timeout + "ms";
    },
    transitionTimingFunction: 'ease-out'
  },
  exit: {
    opacity: 1
  },
  exitActive: {
    opacity: 0,
    transform: 'translate(20px)',
    transition: function transition(_ref2) {
      var timeout = _ref2.theme.timeout;
      return "opacity " + timeout + "ms, transform " + timeout + "ms";
    }
  }
});

var TransitionShowing = function TransitionShowing(_ref) {
  var children = _ref.children,
      delay = _ref.delay,
      disabled = _ref.disabled,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["children", "delay", "disabled"]);

  var timeout = otherProps.timeout,
      className = otherProps.className;

  var _useState = React.useState(false),
      showed = _useState[0],
      setShowed = _useState[1];

  var classes = useStyles$h({
    theme: {
      timeout: timeout
    }
  });
  React.useEffect(function () {
    if (!disabled && delay !== undefined) {
      setTimeout(function () {
        return setShowed(true);
      }, delay);
    }
  }, []);
  if (disabled) return children;
  return React__default.createElement(reactTransitionGroup.CSSTransition, Object.assign({}, otherProps, {
    "in": showed,
    unmountOnExit: true,
    classNames: _extends({}, classes)
  }), React__default.createElement("div", {
    className: className || ''
  }, children));
};

var useStyles$i = /*#__PURE__*/reactJss.createUseStyles({
  root: {
    opacity: 0,
    transition: function transition(_ref) {
      var timeout = _ref.theme.timeout;
      return "opacity " + timeout + "ms";
    }
  },
  showed: {
    opacity: 1
  }
});

var OpacityShowing = function OpacityShowing(_ref) {
  var _ref$delay = _ref.delay,
      delay = _ref$delay === void 0 ? 0 : _ref$delay,
      _ref$timeout = _ref.timeout,
      timeout = _ref$timeout === void 0 ? 0 : _ref$timeout,
      _ref$disabled = _ref.disabled,
      disabled = _ref$disabled === void 0 ? false : _ref$disabled,
      children = _ref.children;

  var _useState = React.useState(false),
      active = _useState[0],
      setActive = _useState[1];

  var _useStyles = useStyles$i({
    theme: {
      timeout: timeout
    }
  }),
      root = _useStyles.root,
      showed = _useStyles.showed;

  React.useEffect(function () {
    if (!disabled) {
      setTimeout(function () {
        setActive(true);
      }, delay);
    }
  }, []);
  return React__default.createElement("div", {
    className: root + " " + (active || disabled ? showed : '')
  }, children);
};

var animations = {
  transition: TransitionShowing,
  opacity: OpacityShowing
};
var AnimationWrapper = function AnimationWrapper(_ref) {
  var _ref$type = _ref.type,
      type = _ref$type === void 0 ? 'transition' : _ref$type,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["type"]);

  // @ts-ignore
  var Component = animations[type] || React__default.createElement(React__default.Fragment, null, otherProps.children);
  return React__default.createElement(Component, Object.assign({}, otherProps));
};

// node modules
var typeValidator = {
  emptyString: function emptyString(value) {
    return !isEmpty(value);
  },
  email: function email(value) {
    return !value.includes('@');
  }
};
var validator = {
  maxLength: function maxLength(value, options) {
    return value.toString().trim().length > options.value;
  },
  minLength: function minLength(value, options) {
    return value.toString().trim().length < options.value;
  },
  // @ts-ignore
  type: function type(value, _ref) {
    var _type = _ref.value;
    return typeValidator[_type](value);
  }
};
var numberValidator = {
  moreThen: function moreThen(value, options) {
    return !(value > options.value);
  },
  lessThen: function lessThen(value, options) {
    return !(value < options.value);
  },
  equal: function equal(value, options) {
    return value !== options.value;
  }
};

// node modules
var useStyles$j = /*#__PURE__*/reactJss.createUseStyles({
  errorMessageClass: {
    textAlign: 'left',
    padding: '3px 0',
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.error;
    },
    marginTop: '8px'
  },
  validatedInputWrapper: {
    width: '100%'
  },
  hidden: {
    display: "none"
  }
});

var NUMBER_TYPE = 'number';
var numberKeys = {
  lessThen: true,
  moreThen: true,
  equal: true
};
var ValidatedInput = function ValidatedInput(_ref) {
  var toggleValidationListener = _ref.toggleValidationListener,
      onError = _ref.onError,
      onChange = _ref.onChange,
      _ref$validationQuery = _ref.validationQuery,
      validationQuery = _ref$validationQuery === void 0 ? {
    type: 'emptyString'
  } : _ref$validationQuery,
      _ref$errorDelay = _ref.errorDelay,
      errorDelay = _ref$errorDelay === void 0 ? false : _ref$errorDelay,
      _ref$errorDelayTime = _ref.errorDelayTime,
      errorDelayTime = _ref$errorDelayTime === void 0 ? 300 : _ref$errorDelayTime,
      _ref$rootValidatedInp = _ref.rootValidatedInputClass,
      rootValidatedInputClass = _ref$rootValidatedInp === void 0 ? '' : _ref$rootValidatedInp,
      onBlur = _ref.onBlur,
      autoFocus = _ref.autoFocus,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["toggleValidationListener", "errorText", "onError", "onChange", "validationQuery", "errorDelay", "errorDelayTime", "rootValidatedInputClass", "onBlur", "autoFocus"]);

  var touched = React.useRef(Boolean(otherProps.value));

  var _useStyles = useStyles$j({
    theme: theming.useTheme()
  }),
      errorMessageClass = _useStyles.errorMessageClass,
      validatedInputWrapper = _useStyles.validatedInputWrapper,
      hidden = _useStyles.hidden;

  var _useState = React.useState([]),
      errors = _useState[0],
      setErrors = _useState[1];

  var type = validationQuery.type; // @ts-ignore

  var isNumberType = Boolean(type && type.value === NUMBER_TYPE);

  var toggleError = function toggleError(errors) {
    if (onError) onError(Boolean(errors.length));
    setErrors(errors);
  };

  var _useRef = React.useRef(debounce(toggleError, errorDelayTime)),
      delayedToggleError = _useRef.current;

  var handleBlur = function handleBlur(e) {
    if (!touched.current) {
      touched.current = true;
      var _e$target$value = e.target.value,
          value = _e$target$value === void 0 ? '' : _e$target$value;
      if (!isNumberType) validate(value);else validateNumber(value);
    }

    if (onBlur) {
      onBlur(e);
    }
  };

  var validate = function validate(value) {
    var errors = keys(validationQuery).reduce(function (err, key) {
      // @ts-ignore
      var paramValidator = validator[key];

      if (paramValidator) {
        // @ts-ignore
        var param = validationQuery[key]; // @ts-ignore

        var error = paramValidator(value, param); // @ts-ignore

        if (error) err.push(param);
      }

      return err;
    }, []);
    if (errorDelay) delayedToggleError(errors);else toggleError(errors);
  };

  var validateNumber = function validateNumber(value) {
    var errors = keys(type).reduce(function (err, key) {
      // @ts-ignore
      var isCorrectKey = Boolean(numberKeys[key]);

      if (isCorrectKey) {
        // @ts-ignore
        var param = type[key]; // @ts-ignore

        var error = numberValidator[key](Number(value), param); // @ts-ignore

        if (error) err.push(param);
      }

      return err;
    }, []);
    if (errorDelay) delayedToggleError(errors);else toggleError(errors);
  };

  var handleChange = function handleChange(e) {
    if (!touched.current) {
      touched.current = true;
    } // @ts-ignore


    var value = e.target.value;
    if (!isNumberType) validate(value);else validateNumber(value);
    if (onChange) onChange(e);
  };

  var handleKeyDown = function handleKeyDown(e) {
    var onKeyDown = otherProps.onKeyDown;
    if (onKeyDown) onKeyDown(e);
    if (!isNumberType) return;
    var regexp = /[0-9]/;
    var isBackspace = e.key === 'Backspace';
    var isNotNumber = !regexp.test(e.key) && !isBackspace;
    if (isNotNumber) e.preventDefault();
  };

  React.useEffect(function () {
    if (touched.current) {
      var _otherProps$value = otherProps.value,
          value = _otherProps$value === void 0 ? "" : _otherProps$value;
      if (!isNumberType) validate(value);else validateNumber(value);
    }
  }, [toggleValidationListener]);
  var isErrorMessageExist = errors[0] && errors[0].errorMessage;
  return React__default.createElement("div", {
    className: validatedInputWrapper + " " + rootValidatedInputClass
  }, React__default.createElement(Input, Object.assign({
    autoFocus: autoFocus,
    onBlur: handleBlur,
    onKeyDown: handleKeyDown,
    onChange: handleChange,
    error: Boolean(errors[0])
  }, isNumberType ? {
    pattern: "[0-9]*"
  } : {}, otherProps)), React__default.createElement(Typography, {
    className: errorMessageClass + " " + (isErrorMessageExist ? '' : hidden),
    variant: "label"
  }, errors[0] ? errors[0].errorMessage : '1'));
};

var img$7 = "data:image/svg+xml,%3csvg width='22' height='24' viewBox='0 0 22 24' fill='none' xmlns='http://www.w3.org/2000/svg'%3e%3cpath d='M1 0V24' stroke='%23C7C7C7'/%3e%3cpath d='M15.1235 15.9932L20.4266 10.7432H9.82039L15.1235 15.9932Z' fill='%238E8E93'/%3e%3c/svg%3e";

var useStyles$k = /*#__PURE__*/reactJss.createUseStyles({
  '@font-face': {
    fontFamily: "SF Pro Text",
    src: "url('" + SFProText + "') format(\"opentype\")"
  },
  root: /*#__PURE__*/_extends({}, labelWrapperRoot, {
    height: 45
  }),
  labelClass: /*#__PURE__*/_extends({}, labelClassName),
  selectClass: /*#__PURE__*/_extends({}, inputSelectCommonStylesProps, {
    color: 'transparent',
    transition: 'color .5s ease-out .2s',
    paddingRight: 30,
    fontFamily: "SF Pro Text"
  }),
  active: /*#__PURE__*/_extends({}, activeLabelClassName),
  activeSelect: {
    color: function color(_ref) {
      var palette = _ref.theme.palette;
      return palette.black;
    }
  },
  arrowWrapper: /*#__PURE__*/_extends({}, alignment.center, {
    position: 'absolute',
    right: 4,
    height: 23,
    width: 30,
    top: '50%',
    transform: 'translate(0, -50%)',
    zIndex: -1
  }),
  disabledClass: /*#__PURE__*/_extends({}, disabled),
  errorClass: /*#__PURE__*/_extends({}, errorClass),
  hideFirstOption: {
    display: "none"
  }
});

var defaultValue = {
  value: '',
  displayValue: ''
};
var Select = function Select(_ref) {
  var _ref$error = _ref.error,
      error = _ref$error === void 0 ? false : _ref$error,
      _ref$rootClassName = _ref.rootClassName,
      rootClassName = _ref$rootClassName === void 0 ? '' : _ref$rootClassName,
      _ref$selectClassName = _ref.selectClassName,
      selectClassName = _ref$selectClassName === void 0 ? '' : _ref$selectClassName,
      _ref$options = _ref.options,
      options = _ref$options === void 0 ? [] : _ref$options,
      placeholder = _ref.placeholder,
      _ref$value = _ref.value,
      value = _ref$value === void 0 ? defaultValue : _ref$value,
      onChange = _ref.onChange,
      disabled = _ref.disabled,
      otherProps = _objectWithoutPropertiesLoose(_ref, ["error", "rootClassName", "selectClassName", "options", "placeholder", "value", "onChange", "disabled"]);

  var selectedValue = value.value;

  var _useStyles = useStyles$k({
    theme: theming.useTheme()
  }),
      root = _useStyles.root,
      labelClass = _useStyles.labelClass,
      selectClass = _useStyles.selectClass,
      active = _useStyles.active,
      activeSelect = _useStyles.activeSelect,
      arrowWrapper = _useStyles.arrowWrapper,
      disabledClass = _useStyles.disabledClass,
      errorClass = _useStyles.errorClass,
      hideFirstOption = _useStyles.hideFirstOption;

  var rootClass = root + " " + rootClassName + " " + (disabled ? disabledClass : '') + " " + (error ? errorClass : '');
  var labelClassName = labelClass + " " + (selectedValue !== '' ? active : '');
  var selectRootClassName = selectClass + " " + selectClassName + " " + (selectedValue ? activeSelect : '');

  var handleChange = function handleChange(e) {
    if (onChange) {
      onChange(e);
    }
  };

  return React__default.createElement("div", {
    className: rootClass
  }, placeholder && React__default.createElement(Typography, {
    variant: "body2",
    className: labelClassName
  }, placeholder), React__default.createElement("div", {
    className: arrowWrapper
  }, React__default.createElement("img", {
    src: img$7,
    alt: ""
  })), React__default.createElement("select", Object.assign({
    disabled: disabled,
    onChange: handleChange,
    value: selectedValue,
    className: selectRootClassName
  }, otherProps), React__default.createElement("option", {
    disabled: true,
    className: hideFirstOption
  }), React__default.createElement("option", {
    disabled: true,
    value: ""
  }, placeholder), options.map(function (_ref2) {
    var value = _ref2.value,
        displayValue = _ref2.displayValue;
    return React__default.createElement("option", {
      key: value,
      value: value
    }, displayValue);
  })));
};

var img$8 = "data:image/svg+xml,%3csvg width='20' height='21' viewBox='0 0 20 21' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cg clip-path='url(%23clip0)'%3e %3cpath d='M14.9935 6.7192C14.6856 6.3946 14.1724 6.3803 13.8473 6.68893L8.67105 11.5979L6.20215 9.06299C5.88945 8.74217 5.37676 8.73514 5.05566 9.04787C4.73484 9.36029 4.72808 9.87354 5.04051 10.1944L8.06754 13.3022C8.22617 13.4652 8.43699 13.5473 8.64836 13.5473C8.84891 13.5473 9.04945 13.4733 9.20648 13.3249L14.9632 7.86545C15.2881 7.55733 15.3018 7.04409 14.9935 6.7192Z' fill='%2397C75A'/%3e %3cpath d='M10 0.00708008C4.48594 0.00708008 0 4.49302 0 10.0071C0 15.5211 4.48594 20.0071 10 20.0071C15.5141 20.0071 20 15.5211 20 10.0071C20 4.49302 15.5141 0.00708008 10 0.00708008ZM10 18.3855C5.38027 18.3855 1.6216 14.6271 1.6216 10.0071C1.6216 5.38735 5.38023 1.62868 10 1.62868C14.62 1.62868 18.3784 5.38731 18.3784 10.0071C18.3784 14.6271 14.62 18.3855 10 18.3855Z' fill='%2397C75A'/%3e %3c/g%3e %3cdefs%3e %3cclipPath id='clip0'%3e %3crect width='20' height='20' fill='white' transform='translate(0 0.00708008)'/%3e %3c/clipPath%3e %3c/defs%3e%3c/svg%3e";

var img$9 = "data:image/svg+xml,%3csvg width='20' height='21' viewBox='0 0 20 21' fill='none' xmlns='http://www.w3.org/2000/svg'%3e %3cpath d='M19.25 10.0071C19.25 15.1157 15.1086 19.2571 10 19.2571C4.89137 19.2571 0.75 15.1157 0.75 10.0071C0.75 4.89845 4.89137 0.75708 10 0.75708C15.1086 0.75708 19.25 4.89845 19.25 10.0071Z' stroke='%23CF382F' stroke-width='1.5' stroke-linecap='round' stroke-linejoin='round'/%3e %3cpath d='M10 6.00708V10.0071' stroke='%23CF382F' stroke-width='1.5' stroke-linecap='round' stroke-linejoin='round'/%3e %3cpath d='M10 14.0071H10.01' stroke='%23CF382F' stroke-width='1.5' stroke-linecap='round' stroke-linejoin='round'/%3e%3c/svg%3e";

// node modules
var useStyles$l = /*#__PURE__*/reactJss.createUseStyles({
  block: {
    border: function border(_ref) {
      var variant = _ref.variant;
      return "1px solid " + (variant ? '#CF382F' : '#97C75A');
    },
    background: function background(_ref2) {
      var variant = _ref2.variant;
      return variant ? '#FBEBEB' : '#F0F8E6';
    },
    display: 'flex',
    padding: '12px 17px',
    width: '100%',
    alignItems: 'flex-start',
    boxSizing: 'border-box',
    borderRadius: '10px'
  },
  typography: {
    textAlign: 'left',
    letterSpacing: '0.0008em',
    color: '#121620',
    fontWeight: 'normal',
    marginLeft: '10px',
    width: '100%'
  }
});

// node modules
var InfoBlock = function InfoBlock(_ref) {
  var variant = _ref.variant,
      text = _ref.text;

  var _useStyles = useStyles$l({
    variant: variant === 'error'
  }),
      block = _useStyles.block,
      typography = _useStyles.typography;

  return React__default.createElement("div", {
    className: block
  }, React__default.createElement("img", {
    src: variant === 'error' ? img$9 : img$8,
    alt: "icon"
  }), React__default.createElement(Typography, {
    variant: "h4",
    className: typography
  }, text));
};

// node modules
var ThemeProvider = function ThemeProvider(_ref) {
  var theme = _ref.theme,
      children = _ref.children;
  var ThemeProvider = theming.ThemeProvider;
  return React__default.createElement(ThemeProvider, {
    theme: theme || defaultTheme
  }, children);
};

function createCommonjsModule(fn, module) {
	return module = { exports: {} }, fn(module, module.exports), module.exports;
}

var runtime_1 = createCommonjsModule(function (module) {
/**
 * Copyright (c) 2014-present, Facebook, Inc.
 *
 * This source code is licensed under the MIT license found in the
 * LICENSE file in the root directory of this source tree.
 */

var runtime = (function (exports) {

  var Op = Object.prototype;
  var hasOwn = Op.hasOwnProperty;
  var undefined$1; // More compressible than void 0.
  var $Symbol = typeof Symbol === "function" ? Symbol : {};
  var iteratorSymbol = $Symbol.iterator || "@@iterator";
  var asyncIteratorSymbol = $Symbol.asyncIterator || "@@asyncIterator";
  var toStringTagSymbol = $Symbol.toStringTag || "@@toStringTag";

  function define(obj, key, value) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
    return obj[key];
  }
  try {
    // IE 8 has a broken Object.defineProperty that only works on DOM objects.
    define({}, "");
  } catch (err) {
    define = function(obj, key, value) {
      return obj[key] = value;
    };
  }

  function wrap(innerFn, outerFn, self, tryLocsList) {
    // If outerFn provided and outerFn.prototype is a Generator, then outerFn.prototype instanceof Generator.
    var protoGenerator = outerFn && outerFn.prototype instanceof Generator ? outerFn : Generator;
    var generator = Object.create(protoGenerator.prototype);
    var context = new Context(tryLocsList || []);

    // The ._invoke method unifies the implementations of the .next,
    // .throw, and .return methods.
    generator._invoke = makeInvokeMethod(innerFn, self, context);

    return generator;
  }
  exports.wrap = wrap;

  // Try/catch helper to minimize deoptimizations. Returns a completion
  // record like context.tryEntries[i].completion. This interface could
  // have been (and was previously) designed to take a closure to be
  // invoked without arguments, but in all the cases we care about we
  // already have an existing method we want to call, so there's no need
  // to create a new function object. We can even get away with assuming
  // the method takes exactly one argument, since that happens to be true
  // in every case, so we don't have to touch the arguments object. The
  // only additional allocation required is the completion record, which
  // has a stable shape and so hopefully should be cheap to allocate.
  function tryCatch(fn, obj, arg) {
    try {
      return { type: "normal", arg: fn.call(obj, arg) };
    } catch (err) {
      return { type: "throw", arg: err };
    }
  }

  var GenStateSuspendedStart = "suspendedStart";
  var GenStateSuspendedYield = "suspendedYield";
  var GenStateExecuting = "executing";
  var GenStateCompleted = "completed";

  // Returning this object from the innerFn has the same effect as
  // breaking out of the dispatch switch statement.
  var ContinueSentinel = {};

  // Dummy constructor functions that we use as the .constructor and
  // .constructor.prototype properties for functions that return Generator
  // objects. For full spec compliance, you may wish to configure your
  // minifier not to mangle the names of these two functions.
  function Generator() {}
  function GeneratorFunction() {}
  function GeneratorFunctionPrototype() {}

  // This is a polyfill for %IteratorPrototype% for environments that
  // don't natively support it.
  var IteratorPrototype = {};
  IteratorPrototype[iteratorSymbol] = function () {
    return this;
  };

  var getProto = Object.getPrototypeOf;
  var NativeIteratorPrototype = getProto && getProto(getProto(values([])));
  if (NativeIteratorPrototype &&
      NativeIteratorPrototype !== Op &&
      hasOwn.call(NativeIteratorPrototype, iteratorSymbol)) {
    // This environment has a native %IteratorPrototype%; use it instead
    // of the polyfill.
    IteratorPrototype = NativeIteratorPrototype;
  }

  var Gp = GeneratorFunctionPrototype.prototype =
    Generator.prototype = Object.create(IteratorPrototype);
  GeneratorFunction.prototype = Gp.constructor = GeneratorFunctionPrototype;
  GeneratorFunctionPrototype.constructor = GeneratorFunction;
  GeneratorFunction.displayName = define(
    GeneratorFunctionPrototype,
    toStringTagSymbol,
    "GeneratorFunction"
  );

  // Helper for defining the .next, .throw, and .return methods of the
  // Iterator interface in terms of a single ._invoke method.
  function defineIteratorMethods(prototype) {
    ["next", "throw", "return"].forEach(function(method) {
      define(prototype, method, function(arg) {
        return this._invoke(method, arg);
      });
    });
  }

  exports.isGeneratorFunction = function(genFun) {
    var ctor = typeof genFun === "function" && genFun.constructor;
    return ctor
      ? ctor === GeneratorFunction ||
        // For the native GeneratorFunction constructor, the best we can
        // do is to check its .name property.
        (ctor.displayName || ctor.name) === "GeneratorFunction"
      : false;
  };

  exports.mark = function(genFun) {
    if (Object.setPrototypeOf) {
      Object.setPrototypeOf(genFun, GeneratorFunctionPrototype);
    } else {
      genFun.__proto__ = GeneratorFunctionPrototype;
      define(genFun, toStringTagSymbol, "GeneratorFunction");
    }
    genFun.prototype = Object.create(Gp);
    return genFun;
  };

  // Within the body of any async function, `await x` is transformed to
  // `yield regeneratorRuntime.awrap(x)`, so that the runtime can test
  // `hasOwn.call(value, "__await")` to determine if the yielded value is
  // meant to be awaited.
  exports.awrap = function(arg) {
    return { __await: arg };
  };

  function AsyncIterator(generator, PromiseImpl) {
    function invoke(method, arg, resolve, reject) {
      var record = tryCatch(generator[method], generator, arg);
      if (record.type === "throw") {
        reject(record.arg);
      } else {
        var result = record.arg;
        var value = result.value;
        if (value &&
            typeof value === "object" &&
            hasOwn.call(value, "__await")) {
          return PromiseImpl.resolve(value.__await).then(function(value) {
            invoke("next", value, resolve, reject);
          }, function(err) {
            invoke("throw", err, resolve, reject);
          });
        }

        return PromiseImpl.resolve(value).then(function(unwrapped) {
          // When a yielded Promise is resolved, its final value becomes
          // the .value of the Promise<{value,done}> result for the
          // current iteration.
          result.value = unwrapped;
          resolve(result);
        }, function(error) {
          // If a rejected Promise was yielded, throw the rejection back
          // into the async generator function so it can be handled there.
          return invoke("throw", error, resolve, reject);
        });
      }
    }

    var previousPromise;

    function enqueue(method, arg) {
      function callInvokeWithMethodAndArg() {
        return new PromiseImpl(function(resolve, reject) {
          invoke(method, arg, resolve, reject);
        });
      }

      return previousPromise =
        // If enqueue has been called before, then we want to wait until
        // all previous Promises have been resolved before calling invoke,
        // so that results are always delivered in the correct order. If
        // enqueue has not been called before, then it is important to
        // call invoke immediately, without waiting on a callback to fire,
        // so that the async generator function has the opportunity to do
        // any necessary setup in a predictable way. This predictability
        // is why the Promise constructor synchronously invokes its
        // executor callback, and why async functions synchronously
        // execute code before the first await. Since we implement simple
        // async functions in terms of async generators, it is especially
        // important to get this right, even though it requires care.
        previousPromise ? previousPromise.then(
          callInvokeWithMethodAndArg,
          // Avoid propagating failures to Promises returned by later
          // invocations of the iterator.
          callInvokeWithMethodAndArg
        ) : callInvokeWithMethodAndArg();
    }

    // Define the unified helper method that is used to implement .next,
    // .throw, and .return (see defineIteratorMethods).
    this._invoke = enqueue;
  }

  defineIteratorMethods(AsyncIterator.prototype);
  AsyncIterator.prototype[asyncIteratorSymbol] = function () {
    return this;
  };
  exports.AsyncIterator = AsyncIterator;

  // Note that simple async functions are implemented on top of
  // AsyncIterator objects; they just return a Promise for the value of
  // the final result produced by the iterator.
  exports.async = function(innerFn, outerFn, self, tryLocsList, PromiseImpl) {
    if (PromiseImpl === void 0) PromiseImpl = Promise;

    var iter = new AsyncIterator(
      wrap(innerFn, outerFn, self, tryLocsList),
      PromiseImpl
    );

    return exports.isGeneratorFunction(outerFn)
      ? iter // If outerFn is a generator, return the full iterator.
      : iter.next().then(function(result) {
          return result.done ? result.value : iter.next();
        });
  };

  function makeInvokeMethod(innerFn, self, context) {
    var state = GenStateSuspendedStart;

    return function invoke(method, arg) {
      if (state === GenStateExecuting) {
        throw new Error("Generator is already running");
      }

      if (state === GenStateCompleted) {
        if (method === "throw") {
          throw arg;
        }

        // Be forgiving, per 25.3.3.3.3 of the spec:
        // https://people.mozilla.org/~jorendorff/es6-draft.html#sec-generatorresume
        return doneResult();
      }

      context.method = method;
      context.arg = arg;

      while (true) {
        var delegate = context.delegate;
        if (delegate) {
          var delegateResult = maybeInvokeDelegate(delegate, context);
          if (delegateResult) {
            if (delegateResult === ContinueSentinel) continue;
            return delegateResult;
          }
        }

        if (context.method === "next") {
          // Setting context._sent for legacy support of Babel's
          // function.sent implementation.
          context.sent = context._sent = context.arg;

        } else if (context.method === "throw") {
          if (state === GenStateSuspendedStart) {
            state = GenStateCompleted;
            throw context.arg;
          }

          context.dispatchException(context.arg);

        } else if (context.method === "return") {
          context.abrupt("return", context.arg);
        }

        state = GenStateExecuting;

        var record = tryCatch(innerFn, self, context);
        if (record.type === "normal") {
          // If an exception is thrown from innerFn, we leave state ===
          // GenStateExecuting and loop back for another invocation.
          state = context.done
            ? GenStateCompleted
            : GenStateSuspendedYield;

          if (record.arg === ContinueSentinel) {
            continue;
          }

          return {
            value: record.arg,
            done: context.done
          };

        } else if (record.type === "throw") {
          state = GenStateCompleted;
          // Dispatch the exception by looping back around to the
          // context.dispatchException(context.arg) call above.
          context.method = "throw";
          context.arg = record.arg;
        }
      }
    };
  }

  // Call delegate.iterator[context.method](context.arg) and handle the
  // result, either by returning a { value, done } result from the
  // delegate iterator, or by modifying context.method and context.arg,
  // setting context.delegate to null, and returning the ContinueSentinel.
  function maybeInvokeDelegate(delegate, context) {
    var method = delegate.iterator[context.method];
    if (method === undefined$1) {
      // A .throw or .return when the delegate iterator has no .throw
      // method always terminates the yield* loop.
      context.delegate = null;

      if (context.method === "throw") {
        // Note: ["return"] must be used for ES3 parsing compatibility.
        if (delegate.iterator["return"]) {
          // If the delegate iterator has a return method, give it a
          // chance to clean up.
          context.method = "return";
          context.arg = undefined$1;
          maybeInvokeDelegate(delegate, context);

          if (context.method === "throw") {
            // If maybeInvokeDelegate(context) changed context.method from
            // "return" to "throw", let that override the TypeError below.
            return ContinueSentinel;
          }
        }

        context.method = "throw";
        context.arg = new TypeError(
          "The iterator does not provide a 'throw' method");
      }

      return ContinueSentinel;
    }

    var record = tryCatch(method, delegate.iterator, context.arg);

    if (record.type === "throw") {
      context.method = "throw";
      context.arg = record.arg;
      context.delegate = null;
      return ContinueSentinel;
    }

    var info = record.arg;

    if (! info) {
      context.method = "throw";
      context.arg = new TypeError("iterator result is not an object");
      context.delegate = null;
      return ContinueSentinel;
    }

    if (info.done) {
      // Assign the result of the finished delegate to the temporary
      // variable specified by delegate.resultName (see delegateYield).
      context[delegate.resultName] = info.value;

      // Resume execution at the desired location (see delegateYield).
      context.next = delegate.nextLoc;

      // If context.method was "throw" but the delegate handled the
      // exception, let the outer generator proceed normally. If
      // context.method was "next", forget context.arg since it has been
      // "consumed" by the delegate iterator. If context.method was
      // "return", allow the original .return call to continue in the
      // outer generator.
      if (context.method !== "return") {
        context.method = "next";
        context.arg = undefined$1;
      }

    } else {
      // Re-yield the result returned by the delegate method.
      return info;
    }

    // The delegate iterator is finished, so forget it and continue with
    // the outer generator.
    context.delegate = null;
    return ContinueSentinel;
  }

  // Define Generator.prototype.{next,throw,return} in terms of the
  // unified ._invoke helper method.
  defineIteratorMethods(Gp);

  define(Gp, toStringTagSymbol, "Generator");

  // A Generator should always return itself as the iterator object when the
  // @@iterator function is called on it. Some browsers' implementations of the
  // iterator prototype chain incorrectly implement this, causing the Generator
  // object to not be returned from this call. This ensures that doesn't happen.
  // See https://github.com/facebook/regenerator/issues/274 for more details.
  Gp[iteratorSymbol] = function() {
    return this;
  };

  Gp.toString = function() {
    return "[object Generator]";
  };

  function pushTryEntry(locs) {
    var entry = { tryLoc: locs[0] };

    if (1 in locs) {
      entry.catchLoc = locs[1];
    }

    if (2 in locs) {
      entry.finallyLoc = locs[2];
      entry.afterLoc = locs[3];
    }

    this.tryEntries.push(entry);
  }

  function resetTryEntry(entry) {
    var record = entry.completion || {};
    record.type = "normal";
    delete record.arg;
    entry.completion = record;
  }

  function Context(tryLocsList) {
    // The root entry object (effectively a try statement without a catch
    // or a finally block) gives us a place to store values thrown from
    // locations where there is no enclosing try statement.
    this.tryEntries = [{ tryLoc: "root" }];
    tryLocsList.forEach(pushTryEntry, this);
    this.reset(true);
  }

  exports.keys = function(object) {
    var keys = [];
    for (var key in object) {
      keys.push(key);
    }
    keys.reverse();

    // Rather than returning an object with a next method, we keep
    // things simple and return the next function itself.
    return function next() {
      while (keys.length) {
        var key = keys.pop();
        if (key in object) {
          next.value = key;
          next.done = false;
          return next;
        }
      }

      // To avoid creating an additional object, we just hang the .value
      // and .done properties off the next function object itself. This
      // also ensures that the minifier will not anonymize the function.
      next.done = true;
      return next;
    };
  };

  function values(iterable) {
    if (iterable) {
      var iteratorMethod = iterable[iteratorSymbol];
      if (iteratorMethod) {
        return iteratorMethod.call(iterable);
      }

      if (typeof iterable.next === "function") {
        return iterable;
      }

      if (!isNaN(iterable.length)) {
        var i = -1, next = function next() {
          while (++i < iterable.length) {
            if (hasOwn.call(iterable, i)) {
              next.value = iterable[i];
              next.done = false;
              return next;
            }
          }

          next.value = undefined$1;
          next.done = true;

          return next;
        };

        return next.next = next;
      }
    }

    // Return an iterator with no values.
    return { next: doneResult };
  }
  exports.values = values;

  function doneResult() {
    return { value: undefined$1, done: true };
  }

  Context.prototype = {
    constructor: Context,

    reset: function(skipTempReset) {
      this.prev = 0;
      this.next = 0;
      // Resetting context._sent for legacy support of Babel's
      // function.sent implementation.
      this.sent = this._sent = undefined$1;
      this.done = false;
      this.delegate = null;

      this.method = "next";
      this.arg = undefined$1;

      this.tryEntries.forEach(resetTryEntry);

      if (!skipTempReset) {
        for (var name in this) {
          // Not sure about the optimal order of these conditions:
          if (name.charAt(0) === "t" &&
              hasOwn.call(this, name) &&
              !isNaN(+name.slice(1))) {
            this[name] = undefined$1;
          }
        }
      }
    },

    stop: function() {
      this.done = true;

      var rootEntry = this.tryEntries[0];
      var rootRecord = rootEntry.completion;
      if (rootRecord.type === "throw") {
        throw rootRecord.arg;
      }

      return this.rval;
    },

    dispatchException: function(exception) {
      if (this.done) {
        throw exception;
      }

      var context = this;
      function handle(loc, caught) {
        record.type = "throw";
        record.arg = exception;
        context.next = loc;

        if (caught) {
          // If the dispatched exception was caught by a catch block,
          // then let that catch block handle the exception normally.
          context.method = "next";
          context.arg = undefined$1;
        }

        return !! caught;
      }

      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        var record = entry.completion;

        if (entry.tryLoc === "root") {
          // Exception thrown outside of any try block that could handle
          // it, so set the completion value of the entire function to
          // throw the exception.
          return handle("end");
        }

        if (entry.tryLoc <= this.prev) {
          var hasCatch = hasOwn.call(entry, "catchLoc");
          var hasFinally = hasOwn.call(entry, "finallyLoc");

          if (hasCatch && hasFinally) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            } else if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else if (hasCatch) {
            if (this.prev < entry.catchLoc) {
              return handle(entry.catchLoc, true);
            }

          } else if (hasFinally) {
            if (this.prev < entry.finallyLoc) {
              return handle(entry.finallyLoc);
            }

          } else {
            throw new Error("try statement without catch or finally");
          }
        }
      }
    },

    abrupt: function(type, arg) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc <= this.prev &&
            hasOwn.call(entry, "finallyLoc") &&
            this.prev < entry.finallyLoc) {
          var finallyEntry = entry;
          break;
        }
      }

      if (finallyEntry &&
          (type === "break" ||
           type === "continue") &&
          finallyEntry.tryLoc <= arg &&
          arg <= finallyEntry.finallyLoc) {
        // Ignore the finally entry if control is not jumping to a
        // location outside the try/catch block.
        finallyEntry = null;
      }

      var record = finallyEntry ? finallyEntry.completion : {};
      record.type = type;
      record.arg = arg;

      if (finallyEntry) {
        this.method = "next";
        this.next = finallyEntry.finallyLoc;
        return ContinueSentinel;
      }

      return this.complete(record);
    },

    complete: function(record, afterLoc) {
      if (record.type === "throw") {
        throw record.arg;
      }

      if (record.type === "break" ||
          record.type === "continue") {
        this.next = record.arg;
      } else if (record.type === "return") {
        this.rval = this.arg = record.arg;
        this.method = "return";
        this.next = "end";
      } else if (record.type === "normal" && afterLoc) {
        this.next = afterLoc;
      }

      return ContinueSentinel;
    },

    finish: function(finallyLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.finallyLoc === finallyLoc) {
          this.complete(entry.completion, entry.afterLoc);
          resetTryEntry(entry);
          return ContinueSentinel;
        }
      }
    },

    "catch": function(tryLoc) {
      for (var i = this.tryEntries.length - 1; i >= 0; --i) {
        var entry = this.tryEntries[i];
        if (entry.tryLoc === tryLoc) {
          var record = entry.completion;
          if (record.type === "throw") {
            var thrown = record.arg;
            resetTryEntry(entry);
          }
          return thrown;
        }
      }

      // The context.catch method must only be called with a location
      // argument that corresponds to a known catch block.
      throw new Error("illegal catch attempt");
    },

    delegateYield: function(iterable, resultName, nextLoc) {
      this.delegate = {
        iterator: values(iterable),
        resultName: resultName,
        nextLoc: nextLoc
      };

      if (this.method === "next") {
        // Deliberately forget the last sent value so that we don't
        // accidentally pass it on to the delegate.
        this.arg = undefined$1;
      }

      return ContinueSentinel;
    }
  };

  // Regardless of whether this script is executing as a CommonJS module
  // or not, return the runtime object so that we can declare the variable
  // regeneratorRuntime in the outer scope, which allows this module to be
  // injected easily by `bin/regenerator --include-runtime script.js`.
  return exports;

}(
  // If this script is executing as a CommonJS module, use module.exports
  // as the regeneratorRuntime namespace. Otherwise create a new empty
  // object. Either way, the resulting object will be used to initialize
  // the regeneratorRuntime variable at the top of this file.
   module.exports 
));

try {
  regeneratorRuntime = runtime;
} catch (accidentalStrictMode) {
  // This module should not be running in strict mode, so the above
  // assignment should always work unless something is misconfigured. Just
  // in case runtime.js accidentally runs in strict mode, we can escape
  // strict mode using a global Function call. This could conceivably fail
  // if a Content Security Policy forbids using Function, but in that case
  // the proper solution is to fix the accidental strict mode problem. If
  // you've misconfigured your bundler to force strict mode and applied a
  // CSP to forbid Function, and you're not willing to fix either of those
  // problems, please detail your unique predicament in a GitHub issue.
  Function("r", "regeneratorRuntime = r")(runtime);
}
});

var PreloadImg = /*#__PURE__*/function () {
  function PreloadImg(listOfFolders, bucket, firebaseConfig) {
    var _this = this;

    this.img = {};
    this.loadedDestination = [];

    this.getLinkFromConfig = function (config) {
      var _config$thumbnails, _config$thumbnails$im;

      return config == null ? void 0 : (_config$thumbnails = config.thumbnails) == null ? void 0 : (_config$thumbnails$im = _config$thumbnails.img) == null ? void 0 : _config$thumbnails$im.path;
    };

    this.getImage = function (path) {
      if (!path) return;
      if (!_this.img[path]) void _this.loadImage(path);
      return _this.img[path];
    };

    this.startPreloadImage = /*#__PURE__*/function () {
      var _ref = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee(config, destination) {
        var link;
        return runtime_1.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                _context.prev = 0;
                link = _this.getLinkFromConfig(config);

                if (!(!link || _this.img[link])) {
                  _context.next = 4;
                  break;
                }

                return _context.abrupt("return");

              case 4:
                _context.next = 6;
                return _this.loadImage(link);

              case 6:
                _this.loadedDestination = [].concat(_this.loadedDestination, [destination]);
                _context.next = 12;
                break;

              case 9:
                _context.prev = 9;
                _context.t0 = _context["catch"](0);
                _this.loadedDestination = [].concat(_this.loadedDestination);

              case 12:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, null, [[0, 9]]);
      }));

      return function (_x, _x2) {
        return _ref.apply(this, arguments);
      };
    }();

    this.storage = storage.getStorage(app.initializeApp(firebaseConfig));
    var listOfPathToImages = listOfFolders.map( /*#__PURE__*/function () {
      var _ref2 = _asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee2(folder) {
        var listRef, _yield$listAll, items;

        return runtime_1.wrap(function _callee2$(_context2) {
          while (1) {
            switch (_context2.prev = _context2.next) {
              case 0:
                listRef = storage.ref(_this.storage, bucket + "/" + folder);
                _context2.next = 3;
                return storage.listAll(listRef);

              case 3:
                _yield$listAll = _context2.sent;
                items = _yield$listAll.items;
                return _context2.abrupt("return", items.map(function (item) {
                  return item.fullPath;
                }));

              case 6:
              case "end":
                return _context2.stop();
            }
          }
        }, _callee2);
      }));

      return function (_x3) {
        return _ref2.apply(this, arguments);
      };
    }());
    Promise.all(listOfPathToImages).then(function (res) {
      var flattedList = res.flat();
      flattedList.map(function (link) {
        return _this.loadImage(link);
      });
    });
    mobx.makeAutoObservable(this);
  }

  var _proto = PreloadImg.prototype;

  _proto.loadImage = /*#__PURE__*/function () {
    var _loadImage = /*#__PURE__*/_asyncToGenerator( /*#__PURE__*/runtime_1.mark(function _callee3(path) {
      var _res, url, res, loading;

      return runtime_1.wrap(function _callee3$(_context3) {
        while (1) {
          switch (_context3.prev = _context3.next) {
            case 0:
              _context3.prev = 0;

              if (!(!path || this.img[path])) {
                _context3.next = 3;
                break;
              }

              return _context3.abrupt("return");

            case 3:
              _context3.next = 5;
              return storage.getDownloadURL(storage.ref(this.storage, path));

            case 5:
              url = _context3.sent;

              if (!path.includes('.json')) {
                _context3.next = 12;
                break;
              }

              _context3.next = 9;
              return axios.get(url);

            case 9:
              res = _context3.sent;
              _context3.next = 14;
              break;

            case 12:
              loading = new Image();
              loading.src = url;

            case 14:
              this.img[path] = ((_res = res) == null ? void 0 : _res.data) || url;
              _context3.next = 20;
              break;

            case 17:
              _context3.prev = 17;
              _context3.t0 = _context3["catch"](0);
              this.img[path] = {};

            case 20:
            case "end":
              return _context3.stop();
          }
        }
      }, _callee3, this, [[0, 17]]);
    }));

    function loadImage(_x4) {
      return _loadImage.apply(this, arguments);
    }

    return loadImage;
  }();

  return PreloadImg;
}();

var LocalStorageService = /*#__PURE__*/function () {
  function LocalStorageService() {}

  var _proto = LocalStorageService.prototype;

  _proto.getItem = function getItem(name) {
    return localStorage.getItem(name);
  };

  _proto.setItem = function setItem(name, value) {
    localStorage.setItem(name, value);
    window.dispatchEvent(createUpdateStorageCustomEvent(value, name));
  };

  _proto.intitWatchVP = function intitWatchVP(watchingLocalStoradgeKey) {
    return function (watchers) {
      window.addEventListener(UPDATE_STORAGE_EVENT, function (e) {
        if (watchingLocalStoradgeKey === e.detail.keyEvent) {
          watchers.forEach(function (watcher) {
            return watcher(e.detail.value);
          });
        }
      });
    };
  };

  _proto.getLocalStorageData = function getLocalStorageData(keys) {
    var storageData = keys.reduce(function (data, key) {
      try {
        var value = localStorage.getItem(key);
        data[key] = JSON.parse(value);
      } catch (_unused) {
        data[key] = localStorage.getItem(key);
      }

      return data;
    }, {});
    return storageData;
  };

  return LocalStorageService;
}();

var localStorageService = /*#__PURE__*/new LocalStorageService();

function evaluateExpressionTree(tree) {
  // #TODO here we able extend or logic for transpile string logical expression to real one

  /* tslint:disable triple-equals*/
  if (tree.type == 'Literal') {
    return tree.value;
    /* tslint:disable triple-equals*/
  } else if (tree.type == 'LogicalExpression') {
    /* tslint:disable triple-equals*/
    if (tree.operator == '&&') {
      return evaluateExpressionTree(tree.left) && evaluateExpressionTree(tree.right);
    } else {
      return evaluateExpressionTree(tree.left) || evaluateExpressionTree(tree.right);
    }
    /* tslint:disable triple-equals*/

  } else if (tree.type == 'BinaryExpression') {
    /* tslint:disable triple-equals*/
    if (tree.operator == '==') {
      /* tslint:disable triple-equals*/
      return evaluateExpressionTree(tree.left) == evaluateExpressionTree(tree.right);
    }
  } else {
    // Unexpected node parsed
    return null;
  }
}

//#TODO move destination service to library, because this is very sensetive logic.

var DestinationService = function DestinationService(parser) {
  var _this = this;

  this.parser = function (params) {
    return params;
  };

  this.isExpressionHasLogicalOperators = function (expression) {
    return /AND|OR|and|or|XOR|&&|<=|>=|<|>|!=|==|&|OR*|!|\|{1,2}/gi.test(expression);
  };

  this.parse = function (_ref) {
    var destination = _ref.destination;

    var parsedString = _this.parser(destination);

    if (!_this.isExpressionHasLogicalOperators(parsedString)) return destination;
    return evaluateExpressionTree(jsep(parsedString)) || destination;
  };

  if (parser) this.parser = parser;
};

var DestinationServiceInstance = /*#__PURE__*/new DestinationService(function (text) {
  return TextNormalizer(text, {
    localStorageMode: true,
    tagWrappers: [["*", "p"], ["$", "div"]]
  });
});

var storageListener = function storageListener(action) {
  window.addEventListener(UPDATE_STORAGE_EVENT, function (e) {
    var _e$detail, _e$detail2;

    action({
      key: e == null ? void 0 : (_e$detail = e.detail) == null ? void 0 : _e$detail.keyEvent,
      value: e == null ? void 0 : (_e$detail2 = e.detail) == null ? void 0 : _e$detail2.value
    });
  });
};

var versionWatcher = function versionWatcher(version, cb) {
  var currentVersion = localStorage.getItem('_v');

  if (!currentVersion || version != currentVersion) {
    localStorage.clear();
    localStorage.setItem('_v', version);
    cb();
  }
};

var MAX_YEARS = 121;
var MAX_DAYS_IN_MONTH = 31;
var FEBRUARY_MONTH_FORMAT = '2';
var lastDays = {
  '29': true,
  '30': true,
  '31': true
};

var getDays = function getDays(days) {
  if (days === void 0) {
    days = MAX_DAYS_IN_MONTH;
  }

  return new Array(days).fill(true).map(function (_, i) {
    return {
      value: i + 1,
      displayValue: i + 1
    };
  });
};

var getMonths = function getMonths() {
  return moment.months().map(function (month, i) {
    return {
      value: i + 1,
      displayValue: month
    };
  });
};

var getYears = function getYears() {
  var year = moment().year() - 1;
  return new Array(MAX_YEARS).fill(true).reduce(function (arr, _, i) {
    var value = year - i;
    arr.push({
      value: value,
      displayValue: value
    });
    return arr;
  }, []);
};

var getDefaultDataConfig = function getDefaultDataConfig() {
  return {
    months: getMonths(),
    years: getYears(),
    defaultDays: getDays()
  };
};
var getDaysInMonth = function getDaysInMonth(month, year) {
  return !year ? getDays(moment(month).daysInMonth()) : getDays(moment(year + "-" + month, 'YYYY-MM').daysInMonth());
};
var getCorrectFebruaryDay = function getCorrectFebruaryDay(day, year) {
  // @ts-ignore
  var fabDay = lastDays[day] ? getDaysInMonth(FEBRUARY_MONTH_FORMAT, year).length : day;
  return {
    value: fabDay,
    displayValue: fabDay
  };
};
var parseTimestemp = function parseTimestemp(timestemp) {
  var _moment$unix$format$s = moment.unix(timestemp).format("L").split('/'),
      m = _moment$unix$format$s[0],
      d = _moment$unix$format$s[1],
      y = _moment$unix$format$s[2];

  return {
    day: Number(d).toString(),
    month: Number(m).toString(),
    year: Number(y).toString()
  };
};
var parseToTimestemp = function parseToTimestemp(date) {
  return moment(date).format('X');
};
var parseTimestempHours = function parseTimestempHours(timestemp) {
  var _moment$format$split = moment(timestemp).format('MM/DD/YYYY hh:mm A').split(' '),
      hours = _moment$format$split[1],
      time = _moment$format$split[2];

  return {
    hours: hours && Number(hours.split(':')[0]).toString(),
    minutes: hours && Number(hours.split(':')[1]).toString(),
    time: time
  };
};
var paresHoursToTimestempWithDate = function paresHoursToTimestempWithDate(_ref) {
  var dateOfBirth = _ref.dateOfBirth,
      hours = _ref.hours,
      minutes = _ref.minutes,
      time = _ref.time;
  return moment(moment(dateOfBirth).format('L') + " " + hours + ":" + minutes + " " + time, "MM/DD/YYYY HH:mm A").format('x');
};
var parseHoursToTimestemp = function parseHoursToTimestemp(_ref2) {
  var hours = _ref2.hours,
      minutes = _ref2.minutes,
      time = _ref2.time;
  return moment(hours + ":" + minutes + " " + time, 'HH:mm A').format('x');
};

var useDateOfBirth = function useDateOfBirth(date, onDateChanged) {
  var _getDefaultDataConfig = getDefaultDataConfig(),
      months = _getDefaultDataConfig.months,
      years = _getDefaultDataConfig.years,
      defaultDays = _getDefaultDataConfig.defaultDays;

  var _useState = React.useState(defaultDays),
      days = _useState[0],
      setDays = _useState[1];

  var _useState2 = React.useState(),
      day = _useState2[0],
      setDay = _useState2[1];

  var _useState3 = React.useState(),
      month = _useState3[0],
      setMonth = _useState3[1];

  var _useState4 = React.useState(),
      year = _useState4[0],
      setYear = _useState4[1];

  var handleChooseDay = function handleChooseDay(e) {
    var value = days.find(function (_ref) {
      var value = _ref.value;
      return value.toString() === e.target.value;
    });
    setDay(value);
  };

  var handleChooseMonth = function handleChooseMonth(_ref2) {
    var val = _ref2.target.value;
    var value = months.find(function (_ref3) {
      var value = _ref3.value;
      return value.toString() === val;
    });
    setMonth(value);
    var newDays = getDaysInMonth(val, year == null ? void 0 : year.value);

    if (newDays.length !== days.length) {
      setDays(newDays);

      if (val === FEBRUARY_MONTH_FORMAT && day) {
        var febDay = getCorrectFebruaryDay(day.value, year == null ? void 0 : year.value);
        setDay(febDay);
      }
    }
  };

  var handleChooseYear = function handleChooseYear(_ref4) {
    var val = _ref4.target.value;
    var value = years.find(function (_ref5) {
      var value = _ref5.value;
      return value.toString() === val;
    });

    if ((month == null ? void 0 : month.value.toString()) === FEBRUARY_MONTH_FORMAT) {
      var newDays = getDaysInMonth(FEBRUARY_MONTH_FORMAT, val);

      if (newDays.length !== days.length) {
        setDays(newDays);

        if (day && newDays.length < day.value) {
          setDay(newDays[newDays.length - 1]);
        }
      }
    }

    setYear(value);
  };

  React.useEffect(function () {
    if (date) {
      var _parseTimestemp = parseTimestemp(date),
          _day = _parseTimestemp.day,
          _month = _parseTimestemp.month,
          _year = _parseTimestemp.year;

      setDay({
        value: _day,
        displayValue: _day
      });
      setMonth({
        value: _month,
        displayValue: _month
      });
      setYear({
        value: _year,
        displayValue: _year
      });
    }
  }, []);
  React.useEffect(function () {
    if (!day || !month || !year) {
      onDateChanged(null);
      return;
    }

    var unixDate = parseToTimestemp((month == null ? void 0 : month.value) + "/" + (day == null ? void 0 : day.value) + "/" + (year == null ? void 0 : year.value));

    if (onDateChanged) {
      onDateChanged(Number(unixDate));
    }
  }, [year, day, month]);
  return {
    year: year,
    month: month,
    day: day,
    years: years,
    months: months,
    days: days,
    handleChooseDay: handleChooseDay,
    handleChooseMonth: handleChooseMonth,
    handleChooseYear: handleChooseYear
  };
};

var useStyles$m = /*#__PURE__*/reactJss.createUseStyles({
  selectItem: {
    marginBottom: 12
  }
});

var DateOfBirth = function DateOfBirth(_ref) {
  var date = _ref.date,
      onDateChanged = _ref.onDateChanged,
      rootClass = _ref.rootClass,
      itemClass = _ref.itemClass;

  var _useStyles = useStyles$m(),
      selectItem = _useStyles.selectItem;

  var _useDateOfBirth = useDateOfBirth(date, onDateChanged),
      months = _useDateOfBirth.months,
      years = _useDateOfBirth.years,
      days = _useDateOfBirth.days,
      day = _useDateOfBirth.day,
      year = _useDateOfBirth.year,
      month = _useDateOfBirth.month,
      handleChooseDay = _useDateOfBirth.handleChooseDay,
      handleChooseMonth = _useDateOfBirth.handleChooseMonth,
      handleChooseYear = _useDateOfBirth.handleChooseYear;

  var selectItemClass = selectItem + " " + (itemClass || '');
  return React__default.createElement("div", {
    className: rootClass || ''
  }, React__default.createElement(Select, {
    rootClassName: selectItemClass,
    onChange: handleChooseMonth,
    value: month,
    placeholder: "Month",
    options: months
  }), React__default.createElement(Select, {
    rootClassName: selectItemClass,
    onChange: handleChooseDay,
    value: day,
    placeholder: "Day",
    options: days
  }), React__default.createElement(Select, {
    rootClassName: selectItemClass,
    onChange: handleChooseYear,
    value: year,
    placeholder: "Year",
    options: years
  }));
};

var useTimeOfBirth = function useTimeOfBirth(_ref) {
  var onTimeChanged = _ref.onTimeChanged,
      dateOfBirth = _ref.dateOfBirth;

  var _useState = React.useState(''),
      hours = _useState[0],
      setHours = _useState[1];

  var _useState2 = React.useState(''),
      minutes = _useState2[0],
      setMinutes = _useState2[1];

  var _useState3 = React.useState(''),
      time = _useState3[0],
      setTime = _useState3[1];

  var _useState4 = React.useState({
    hours: true,
    minutes: true
  }),
      error = _useState4[0],
      setError = _useState4[1];

  var handleChangeHours = function handleChangeHours(_ref2) {
    var value = _ref2.target.value;
    setHours(value);
  };

  var handleChangeMinutes = function handleChangeMinutes(_ref3) {
    var value = _ref3.target.value;
    setMinutes(value);
  };

  var choosePmTime = function choosePmTime() {
    var newTime = time === PM_TIME ? '' : PM_TIME;
    setTime(newTime);
  };

  var chooseAmTime = function chooseAmTime() {
    var newTime = time === AM_TIME ? '' : AM_TIME;
    setTime(newTime);
  };

  var handleMinuteError = function handleMinuteError(err) {
    setError(_extends({}, error, {
      minutes: err
    }));
  };

  var handleHoursError = function handleHoursError(err) {
    setError(_extends({}, error, {
      hours: err
    }));
  };

  React.useEffect(function () {
    if (dateOfBirth) {
      var _parseTimestempHours = parseTimestempHours(dateOfBirth),
          _hours = _parseTimestempHours.hours,
          _minutes = _parseTimestempHours.minutes,
          _time = _parseTimestempHours.time;

      console.log(_time);
      var isHours = _hours !== undefined;
      var isMinutes = _minutes !== undefined;

      if (isHours) {
        setHours(_hours);
      }

      if (isMinutes) {
        setMinutes(_minutes);
      }

      setError({
        hours: !isHours,
        minutes: !isMinutes
      });

      if (_time) {
        setTime(_time);
      }
    }
  }, []);
  React.useEffect(function () {
    var isError = Object.values(error).some(function (err) {
      return err;
    });
    var isInvalid = isError || !hours || !minutes || !time;

    if (isInvalid) {
      onTimeChanged(null);
      return;
    }

    var timestemp = dateOfBirth ? paresHoursToTimestempWithDate({
      dateOfBirth: dateOfBirth,
      hours: hours,
      minutes: minutes,
      time: time
    }) : parseHoursToTimestemp({
      hours: hours,
      minutes: minutes,
      time: time
    });
    onTimeChanged(Number(timestemp));
  }, [hours, minutes, time]);
  return {
    handleChangeHours: handleChangeHours,
    handleChangeMinutes: handleChangeMinutes,
    choosePmTime: choosePmTime,
    chooseAmTime: chooseAmTime,
    hours: hours,
    minutes: minutes,
    time: time,
    handleMinuteError: handleMinuteError,
    handleHoursError: handleHoursError
  };
};

var useStyles$n = /*#__PURE__*/reactJss.createUseStyles({
  wrapper: {
    display: 'flex'
  },
  inputFirst: {
    marginRight: 8
  },
  buttonRoot: {
    padding: 0,
    display: 'flex',
    justifyContent: 'center',
    alignItems: 'center',
    minWidth: 60,
    height: 48,
    marginLeft: 8
  }
});

var PM_TIME = 'PM';
var AM_TIME = 'AM';
var TimeOfBirth = function TimeOfBirth(_ref) {
  var inputClass = _ref.inputClass,
      buttonClass = _ref.buttonClass,
      props = _objectWithoutPropertiesLoose(_ref, ["inputClass", "buttonClass"]);

  var _useStyles = useStyles$n(),
      wrapper = _useStyles.wrapper,
      buttonRoot = _useStyles.buttonRoot,
      inputFirst = _useStyles.inputFirst;

  var _useTimeOfBirth = useTimeOfBirth(props),
      handleChangeHours = _useTimeOfBirth.handleChangeHours,
      handleChangeMinutes = _useTimeOfBirth.handleChangeMinutes,
      choosePmTime = _useTimeOfBirth.choosePmTime,
      chooseAmTime = _useTimeOfBirth.chooseAmTime,
      handleMinuteError = _useTimeOfBirth.handleMinuteError,
      handleHoursError = _useTimeOfBirth.handleHoursError,
      hours = _useTimeOfBirth.hours,
      minutes = _useTimeOfBirth.minutes,
      time = _useTimeOfBirth.time;

  var buttonRootClass = buttonRoot + " " + (buttonClass || '');
  return React__default.createElement("div", {
    className: wrapper
  }, React__default.createElement(ValidatedInput, {
    label: "HH",
    rootClassName: inputFirst + " " + (inputClass || ''),
    maxLength: 2,
    onError: handleHoursError,
    validationQuery: {
      type: {
        value: "number",
        moreThen: {
          value: 0,
          errorMessage: 'Incorrect time'
        },
        lessThen: {
          value: 13,
          errorMessage: 'Incorrect time'
        }
      }
    },
    onChange: handleChangeHours,
    value: hours
  }), React__default.createElement(ValidatedInput, {
    label: "MM",
    onError: handleMinuteError,
    rootClassName: inputClass || '',
    maxLength: 2,
    validationQuery: {
      type: {
        value: "number",
        moreThen: {
          value: -1,
          errorMessage: 'Incorrect time'
        },
        lessThen: {
          value: 60,
          errorMessage: 'Incorrect time'
        }
      }
    },
    onChange: handleChangeMinutes,
    value: minutes
  }), React__default.createElement(SelectButton, {
    selected: time === AM_TIME,
    onClick: chooseAmTime,
    className: buttonRootClass,
    label: AM_TIME
  }), React__default.createElement(SelectButton, {
    selected: time === PM_TIME,
    onClick: choosePmTime,
    className: buttonRootClass,
    label: PM_TIME
  }));
};

exports.AM_TIME = AM_TIME;
exports.AnimationWrapper = AnimationWrapper;
exports.CheckButton = CheckButton;
exports.CheckButtonPrimary = CheckButtonPrimary;
exports.DateOfBirth = DateOfBirth;
exports.DestinationServiceInstance = DestinationServiceInstance;
exports.Header = Header;
exports.InfoBlock = InfoBlock;
exports.Input = Input;
exports.ModalWindow = ModalWindow;
exports.PM_TIME = PM_TIME;
exports.PreloadImg = PreloadImg;
exports.PriceBlock = PriceBlock;
exports.PriceBlockHint = PriceBlockHint;
exports.PrimaryButton = PrimaryButton;
exports.ProgressBar = ProgressBar;
exports.ProgressBarThin = ProgressBarThin;
exports.ProgressStepper = ProgressStepper;
exports.Select = Select;
exports.SelectButton = SelectButton;
exports.SimpleButton = SimpleButton;
exports.SliderPage = SliderPage;
exports.Tab = Tab;
exports.TextNormalizer = TextNormalizer;
exports.ThemeProvider = ThemeProvider;
exports.TimeOfBirth = TimeOfBirth;
exports.Typography = Typography;
exports.ValidatedInput = ValidatedInput;
exports.localStorageService = localStorageService;
exports.storageListener = storageListener;
exports.useAccessPageChecking = useAccessPageChecking;
exports.useLocalStorage = useLocalStorage;
exports.useMultiClickProtector = useMultiClickProtector;
exports.versionWatcher = versionWatcher;
//# sourceMappingURL=ruby-web-common.cjs.development.js.map
